@@ -211,7 +211,7 @@ bool MyMoneyQifReader::Private::isTransfer(QString& tmp, const QString& leftDeli
   // it's a transfer, extract the account name
   // I've seen entries like this
   //
-  // S[Mehrwertsteuer]/_VATCode_N_I
+  // S[Mehrwertsteuer]/_VATCode_N_I          (The '/' is the Quicken class symbol)
   //
   // so extracting is a bit more complex and we use a regexp for it
   QRegExp exp(QString("\\%1(.*)\\%2(.*)").arg(leftDelim, rightDelim));
@@ -253,7 +253,7 @@ MyMoneyQifReader::MyMoneyQifReader() :
 
   connect(&m_filter, SIGNAL(bytesWritten(qint64)), this, SLOT(slotSendDataToFilter()));
   connect(&m_filter, SIGNAL(readyReadStandardOutput()), this, SLOT(slotReceivedDataFromFilter()));
-  connect(&m_filter, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotImportFinished()));
+  connect(&m_filter, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotImportFinished()));
   connect(&m_filter, SIGNAL(readyReadStandardError()), this, SLOT(slotReceivedErrorFromFilter()));
 }
 
@@ -439,8 +439,17 @@ bool MyMoneyQifReader::startImport(void)
     // start filter process, use 'cat -' as the default filter
     m_filter.clearProgram();
     if (m_qifProfile.filterScriptImport().isEmpty()) {
+#ifdef Q_OS_WIN32                   //krazy:exclude=cpp
+      // this is the Windows equivalent of 'cat -' but since 'type' does not work with stdin
+      // we pass the filename converted to native separators as a parameter
+      m_filter << "cmd.exe";
+      m_filter << "/c";
+      m_filter << "type";
+      m_filter << QDir::toNativeSeparators(m_filename);
+#else
       m_filter << "cat";
       m_filter << "-";
+#endif
     } else {
       m_filter << m_qifProfile.filterScriptImport().split(' ', QString::KeepEmptyParts);
     }
@@ -538,7 +547,7 @@ bool MyMoneyQifReader::finishImport(void)
       ft.commit();
   } catch (MyMoneyException *e) {
     KMessageBox::detailedSorry(0, i18n("Unable to add transactions"),
-                               (e->what() + " " + i18n("thrown in") + " " + e->file() + ":%1").arg(e->line()));
+                               i18n("%1 thrown in %2:%3", e->what(), e->file(), e->line()));
     delete e;
     rc = false;
   }
@@ -868,10 +877,13 @@ void MyMoneyQifReader::processCategoryEntry(void)
   account.setDescription(extractLine('D'));
 
   MyMoneyAccount parentAccount;
-  if (!extractLine('I').isEmpty()) {
+  //The extractline routine will more than likely return 'empty',
+  // so also have to test that either the 'I' or 'E' was detected
+  //and set up accounts accordingly.
+  if ((!extractLine('I').isEmpty()) || (m_extractedLine != -1)) {
     account.setAccountType(MyMoneyAccount::Income);
     parentAccount = file->income();
-  } else if (!extractLine('E').isEmpty()) {
+  } else if ((!extractLine('E').isEmpty()) || (m_extractedLine != -1)) {
     account.setAccountType(MyMoneyAccount::Expense);
     parentAccount = file->expense();
   }
@@ -1027,7 +1039,7 @@ void MyMoneyQifReader::processTransactionEntry(void)
   if (d->firstTransaction) {
     // check if this is an opening balance transaction and process it out of the statement
     if (!payee.isEmpty() && ((payee.toLower() == "opening balance") || KMyMoneyGlobalSettings::qifOpeningBalance().toLower().contains(payee.toLower()))) {
-      createOpeningBalance();
+      createOpeningBalance(d->accountType);
       d->firstTransaction = false;
       return;
     }
@@ -1457,7 +1469,9 @@ void MyMoneyQifReader::processInvestmentTransactionEntry(void)
       tr.m_strBrokerageAccount = tmp;
       transferAccount(tmp);           // make sure the account exists
     } else {
+      tmp = tmp.remove(QRegExp("[\\[\\]]"));//  xAction != true so ignore any'[ and ]'
       tr.m_strInterestCategory = tmp;
+      tr.m_strBrokerageAccount = m_account.brokerageName();
     }
 
     // make sure, we have valid category. Either taken from the L-Record above,
@@ -1492,20 +1506,26 @@ void MyMoneyQifReader::processInvestmentTransactionEntry(void)
       tr.m_strBrokerageAccount = tmp;
       transferAccount(tmp);           // make sure the account exists
     } else {
+      tmp = tmp.remove(QRegExp("[\\[\\]]"));//  xAction != true so ignore any '[ and ]'
       tr.m_strInterestCategory = tmp;
+      tr.m_strBrokerageAccount = m_account.brokerageName();
     }
-
     // make sure, we have a valid category. Either taken from the L-Record above,
     // or derived from the action code
     if (tr.m_strInterestCategory.isEmpty()) {
       tr.m_strInterestCategory = d->typeToAccountName(action);
     }
 
-
-    // For historic reasons (coming from the OFX importer) the statement
-    // reader expects the dividend with a reverse sign. So we just do that.
-    if (action != "miscexp")
+    if (action == "intinc") {
+      MyMoneyMoney price = m_qifProfile.value('I', extractLine('I'));
       tr.m_amount = -(amount - tr.m_fees);
+      if ((!quantity.isZero()) && (!price.isZero()))
+        tr.m_amount = -(quantity * price);
+    } else
+      // For historic reasons (coming from the OFX importer) the statement
+      // reader expects the dividend with a reverse sign. So we just do that.
+      if (action != "miscexp")
+        tr.m_amount = -(amount - tr.m_fees);
 
     if (tr.m_strMemo.isEmpty())
       tr.m_strMemo = (QString("%1 %2").arg(extractLine('Y')).arg(d->typeToAccountName(action))).trimmed();
@@ -1939,7 +1959,7 @@ const QString MyMoneyQifReader::processAccountEntry(bool resetAccountId)
   QString tmp;
 
   account.setName(extractLine('N'));
-  // qDebug("Process account '%s'", account.name().data());
+  //   qDebug("Process account '%s'", account.name().data());
 
   account.setDescription(extractLine('D'));
 
@@ -2072,7 +2092,7 @@ void MyMoneyQifReader::selectOrCreateAccount(const SelectCreateMode mode, MyMone
   if (!msg.isEmpty())
     accountSelect->setWindowTitle(msg);
 
-  it = m_accountTranslation.constFind((leadIn + MyMoneyFile::AccountSeperator + account.name()).toLower());
+  it = m_accountTranslation.constFind(QString(leadIn + MyMoneyFile::AccountSeperator + account.name()).toLower());
   if (it != m_accountTranslation.constEnd()) {
     try {
       account = file->account(*it);
@@ -2147,7 +2167,7 @@ void MyMoneyQifReader::selectOrCreateAccount(const SelectCreateMode mode, MyMone
           if (!accountSelect->selectedAccount().isEmpty()) {
             accountId = accountSelect->selectedAccount();
 
-            m_accountTranslation[(leadIn + MyMoneyFile::AccountSeperator + account.name()).toLower()] = accountId;
+            m_accountTranslation[QString(leadIn + MyMoneyFile::AccountSeperator + account.name()).toLower()] = accountId;
 
             // MMAccount::openingBalance() is where the accountSelect dialog has
             // stashed the opening balance that the user chose.
@@ -2165,7 +2185,7 @@ void MyMoneyQifReader::selectOrCreateAccount(const SelectCreateMode mode, MyMone
                   const MyMoneySecurity&  sec = file->security(account.currencyId());
                   if (KMessageBox::questionYesNo(
                         KMyMoneyUtils::mainWindow(),
-                        i18n("The %1 account currently has an opening balance of %2. This QIF file reports an opening balance of %3. Would you like to overwrite the current balance with the one from the QIF file?", account.name(), split.shares().formatMoney(account, sec), balance.formatMoney(account, sec)),
+                        i18n("The %1 account currently has an opening balance of %2. This QIF file reports an opening balance of %3. Would you like to overwrite the current balance with the one from the QIF file?", account.name(), MyMoneyUtils::formatMoney(split.shares(), account, sec), MyMoneyUtils::formatMoney(balance, account, sec)),
                         i18n("Overwrite opening balance"),
                         KStandardGuiItem::yes(),
                         KStandardGuiItem::no(),
