@@ -64,10 +64,10 @@ KCurrencyEditDlg::KCurrencyEditDlg(QWidget *parent) :
   m_currencyList->header()->setStretchLastSection(true);
   m_currencyList->setContextMenuPolicy(Qt::CustomContextMenu);
 
-  connect(m_currencyList, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(slotOpenContextMenu(const QPoint&)));
-  connect(m_currencyList, SIGNAL(itemActivated(QTreeWidgetItem*, int)), this, SLOT(slotStartEditId()));
+  connect(m_currencyList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotOpenContextMenu(QPoint)));
+  connect(m_currencyList, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(slotStartEditId()));
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadCurrencies()));
-  connect(m_currencyList, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotUpdateCurrency(QTreeWidgetItem*)));
+  connect(m_currencyList, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotUpdateCurrency(QTreeWidgetItem*)));
 
   slotLoadCurrencies();
 
@@ -102,8 +102,8 @@ KCurrencyEditDlg::~KCurrencyEditDlg()
 
 void KCurrencyEditDlg::slotLoadCurrencies(void)
 {
-  disconnect(m_currencyList, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this, SLOT(slotSelectCurrency(QTreeWidgetItem*)));
-  disconnect(m_currencyList, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotRenameCurrency(QTreeWidgetItem*)));
+  disconnect(m_currencyList, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), this, SLOT(slotSelectCurrency(QTreeWidgetItem*)));
+  disconnect(m_currencyList, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotRenameCurrency(QTreeWidgetItem*)));
   QList<MyMoneySecurity> list = MyMoneyFile::instance()->currencyList();
   QList<MyMoneySecurity>::ConstIterator it;
   QTreeWidgetItem *first = 0;
@@ -111,7 +111,14 @@ void KCurrencyEditDlg::slotLoadCurrencies(void)
   QString localCurrency(localeconv()->int_curr_symbol);
   localCurrency.truncate(3);
 
-  QString baseCurrency = MyMoneyFile::instance()->baseCurrency().id();
+  QString baseCurrency;
+  try {
+    baseCurrency = MyMoneyFile::instance()->baseCurrency().id();
+  } catch (MyMoneyException *e) {
+    qDebug("%s", qPrintable(e->what()));
+    delete e;
+  }
+
   // construct a transparent 16x16 pixmap
   QPixmap empty(16, 16);
   QBitmap mask(16, 16);
@@ -145,8 +152,8 @@ void KCurrencyEditDlg::slotLoadCurrencies(void)
 
   m_currencyList->sortItems(0, Qt::AscendingOrder);
 
-  connect(m_currencyList, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this, SLOT(slotSelectCurrency(QTreeWidgetItem*)));
-  connect(m_currencyList, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotRenameCurrency(QTreeWidgetItem*)));
+  connect(m_currencyList, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), this, SLOT(slotSelectCurrency(QTreeWidgetItem*)));
+  connect(m_currencyList, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotRenameCurrency(QTreeWidgetItem*)));
 
   if (first == 0)
     first = m_currencyList->invisibleRootItem()->child(0);
@@ -210,6 +217,13 @@ void KCurrencyEditDlg::slotSelectCurrency(const QString& id)
 void KCurrencyEditDlg::slotSelectCurrency(QTreeWidgetItem *item)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
+  QString baseId;
+  try {
+    baseId = MyMoneyFile::instance()->baseCurrency().id();
+  } catch (MyMoneyException *e) {
+    delete e;
+  }
+
   m_currencyInEditing = false;
 
   if (item) {
@@ -220,7 +234,7 @@ void KCurrencyEditDlg::slotSelectCurrency(QTreeWidgetItem *item)
       delete e;
       m_currency = MyMoneySecurity();
     }
-    button(KDialog::User1)->setDisabled(m_currency.id() == file->baseCurrency().id());
+    button(KDialog::User1)->setDisabled(m_currency.id() == baseId);
     emit selectObject(m_currency);
   }
 }
