@@ -65,7 +65,6 @@ KEquityPriceUpdateDlg::KEquityPriceUpdateDlg(QWidget *parent, const QString& sec
     KEquityPriceUpdateDlgDecl(parent),
     m_fUpdateAll(false)
 {
-  lvEquityList->setRootIsDecorated(false);
   QStringList headerList;
   headerList << i18n("Symbol") << i18nc("Equity name", "Name")
   << i18n("Price") << i18n("Date");
@@ -73,7 +72,8 @@ KEquityPriceUpdateDlg::KEquityPriceUpdateDlg(QWidget *parent, const QString& sec
   lvEquityList->setColumnWidth(NAME_COL, 125);
 
   // This is a "get it up and running" hack.  Will replace this in the future.
-  headerList << "ID" << "Source";
+  headerList << i18nc("Internal identifier", "ID")
+  << i18nc("Online quote source", "Source");
   lvEquityList->setColumnWidth(ID_COL, 0);
 
   lvEquityList->setHeaderLabels(headerList);
@@ -93,8 +93,9 @@ KEquityPriceUpdateDlg::KEquityPriceUpdateDlg(QWidget *parent, const QString& sec
   // for consistency reasons, this accepts the same delimiters as WebPriceQuote::launch()
   QRegExp splitrx("([0-9a-z\\.]+)[^a-z0-9]+([0-9a-z\\.]+)", Qt::CaseInsensitive);
   MyMoneySecurityPair currencyIds;
-  if (splitrx.indexIn(securityId) != -1)
+  if (splitrx.indexIn(securityId) != -1) {
     currencyIds = MyMoneySecurityPair(splitrx.cap(1).toUtf8(), splitrx.cap(2).toUtf8());
+  }
 
   MyMoneyPriceList prices = file->priceList();
   for (MyMoneyPriceList::ConstIterator it_price = prices.constBegin(); it_price != prices.constEnd(); ++it_price) {
@@ -124,7 +125,7 @@ KEquityPriceUpdateDlg::KEquityPriceUpdateDlg(QWidget *parent, const QString& sec
   }
 
   // if list is empty, add the request price pair
-  if (lvEquityList->children().empty()) {
+  if (lvEquityList->invisibleRootItem()->childCount() == 0) {
     addPricePair(currencyIds, true);
   }
 
@@ -133,14 +134,14 @@ KEquityPriceUpdateDlg::KEquityPriceUpdateDlg(QWidget *parent, const QString& sec
   connect(btnUpdateSelected, SIGNAL(clicked()), this, SLOT(slotUpdateSelectedClicked()));
   connect(btnUpdateAll, SIGNAL(clicked()), this, SLOT(slotUpdateAllClicked()));
 
-  connect(&m_webQuote, SIGNAL(quote(const QString&, const QString&, const QDate&, const double&)),
-          this, SLOT(slotReceivedQuote(const QString&, const QString&, const QDate&, const double&)));
-  connect(&m_webQuote, SIGNAL(failed(const QString&, const QString&)),
-          this, SLOT(slotQuoteFailed(const QString&, const QString&)));
-  connect(&m_webQuote, SIGNAL(status(const QString&)),
-          this, SLOT(logStatusMessage(const QString&)));
-  connect(&m_webQuote, SIGNAL(error(const QString&)),
-          this, SLOT(logErrorMessage(const QString&)));
+  connect(&m_webQuote, SIGNAL(quote(QString,QString,QDate,double)),
+          this, SLOT(slotReceivedQuote(QString,QString,QDate,double)));
+  connect(&m_webQuote, SIGNAL(failed(QString,QString)),
+          this, SLOT(slotQuoteFailed(QString,QString)));
+  connect(&m_webQuote, SIGNAL(status(QString)),
+          this, SLOT(logStatusMessage(QString)));
+  connect(&m_webQuote, SIGNAL(error(QString)),
+          this, SLOT(logErrorMessage(QString)));
 
   connect(lvEquityList, SIGNAL(itemSelectionChanged()), this, SLOT(slotUpdateSelection()));
 
