@@ -147,6 +147,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
   MyMoneyFile *file = MyMoneyFile::instance();
 
   // initialize the m_parentAccount member
+  MyMoneyAccount::accountTypeE filterAccountGroup = m_account.accountGroup();
   switch (m_account.accountGroup()) {
     case MyMoneyAccount::Asset:
       m_parentAccount = file->asset();
@@ -165,10 +166,13 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
       break;
     default:
       qDebug("Seems we have an account that hasn't been mapped to the top five");
-      if (m_categoryEditor)
+      if (m_categoryEditor) {
         m_parentAccount = file->income();
-      else
+        filterAccountGroup = MyMoneyAccount::Income;
+      } else {
         m_parentAccount = file->asset();
+        filterAccountGroup = MyMoneyAccount::Asset;
+      }
   }
 
   m_amountGroup->setId(m_grossAmount, 0);
@@ -178,7 +182,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
   m_filterProxyModel = new HierarchyFilterProxyModel(this);
   m_filterProxyModel->setHideClosedAccounts(true);
   m_filterProxyModel->setHideEquityAccounts(true);
-  m_filterProxyModel->addAccountGroup(m_account.accountGroup());
+  m_filterProxyModel->addAccountGroup(filterAccountGroup);
   m_filterProxyModel->setCurrentAccountId(m_account.id());
   m_filterProxyModel->setSourceModel(Models::instance()->accountsModel());
   m_filterProxyModel->setDynamicSortFilter(true);
@@ -231,15 +235,15 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
     typeCombo->addItem(KMyMoneyUtils::accountTypeToString(MyMoneyAccount::Income));
     typeCombo->addItem(KMyMoneyUtils::accountTypeToString(MyMoneyAccount::Expense));
 
-    // Hardcoded but acceptable
+    // Hardcoded but acceptable - if above we set the default to income do the same here
     switch (account.accountType()) {
-      case MyMoneyAccount::Income:
-        typeCombo->setCurrentItem(KMyMoneyUtils::accountTypeToString(MyMoneyAccount::Income), false);
+      case MyMoneyAccount::Expense:
+        typeCombo->setCurrentItem(KMyMoneyUtils::accountTypeToString(MyMoneyAccount::Expense), false);
         break;
 
-      case MyMoneyAccount::Expense:
+      case MyMoneyAccount::Income:
       default:
-        typeCombo->setCurrentItem(KMyMoneyUtils::accountTypeToString(MyMoneyAccount::Expense), false);
+        typeCombo->setCurrentItem(KMyMoneyUtils::accountTypeToString(MyMoneyAccount::Income), false);
         break;
     }
     m_currency->setEnabled(true);
@@ -414,27 +418,27 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
 
   connect(cancelButton, SIGNAL(clicked()), SLOT(reject()));
   connect(createButton, SIGNAL(clicked()), this, SLOT(okClicked()));
-  connect(m_parentAccounts->selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
-          this, SLOT(slotSelectionChanged(QItemSelection, QItemSelection)));
+  connect(m_parentAccounts->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+          this, SLOT(slotSelectionChanged(QItemSelection,QItemSelection)));
   connect(m_qbuttonNew, SIGNAL(clicked()), this, SLOT(slotNewClicked()));
-  connect(typeCombo, SIGNAL(activated(const QString&)),
-          this, SLOT(slotAccountTypeChanged(const QString&)));
+  connect(typeCombo, SIGNAL(activated(QString)),
+          this, SLOT(slotAccountTypeChanged(QString)));
 
-  connect(accountNameEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckFinished()));
+  connect(accountNameEdit, SIGNAL(textChanged(QString)), this, SLOT(slotCheckFinished()));
 
   connect(m_vatCategory, SIGNAL(toggled(bool)), this, SLOT(slotVatChanged(bool)));
   connect(m_vatAssignment, SIGNAL(toggled(bool)), this, SLOT(slotVatAssignmentChanged(bool)));
   connect(m_vatCategory, SIGNAL(toggled(bool)), this, SLOT(slotCheckFinished()));
   connect(m_vatAssignment, SIGNAL(toggled(bool)), this, SLOT(slotCheckFinished()));
-  connect(m_vatRate, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckFinished()));
+  connect(m_vatRate, SIGNAL(textChanged(QString)), this, SLOT(slotCheckFinished()));
   connect(m_vatAccount, SIGNAL(stateChanged()), this, SLOT(slotCheckFinished()));
 
-  connect(m_minBalanceEarlyEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(slotAdjustMinBalanceAbsoluteEdit(const QString&)));
-  connect(m_minBalanceAbsoluteEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(slotAdjustMinBalanceEarlyEdit(const QString&)));
-  connect(m_maxCreditEarlyEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(slotAdjustMaxCreditAbsoluteEdit(const QString&)));
-  connect(m_maxCreditAbsoluteEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(slotAdjustMaxCreditEarlyEdit(const QString&)));
+  connect(m_minBalanceEarlyEdit, SIGNAL(valueChanged(QString)), this, SLOT(slotAdjustMinBalanceAbsoluteEdit(QString)));
+  connect(m_minBalanceAbsoluteEdit, SIGNAL(valueChanged(QString)), this, SLOT(slotAdjustMinBalanceEarlyEdit(QString)));
+  connect(m_maxCreditEarlyEdit, SIGNAL(valueChanged(QString)), this, SLOT(slotAdjustMaxCreditAbsoluteEdit(QString)));
+  connect(m_maxCreditAbsoluteEdit, SIGNAL(valueChanged(QString)), this, SLOT(slotAdjustMaxCreditEarlyEdit(QString)));
 
-  connect(m_qcomboboxInstitutions, SIGNAL(activated(const QString&)), this, SLOT(slotLoadInstitutions(const QString&)));
+  connect(m_qcomboboxInstitutions, SIGNAL(activated(QString)), this, SLOT(slotLoadInstitutions(QString)));
 
   QModelIndex parentIndex = m_filterProxyModel->getSelectedParentAccountIndex();
   m_parentAccounts->expand(parentIndex);
@@ -809,6 +813,9 @@ void KNewAccountDlg::slotAccountTypeChanged(const QString& typeStr)
           break;
       }
       m_account.setAccountType(type);
+      // update the account group displayed in the accounts hierarchy
+      m_filterProxyModel->clear();
+      m_filterProxyModel->addAccountGroup(m_account.accountGroup());
     }
   } catch (MyMoneyException *e) {
     delete e;
