@@ -628,6 +628,25 @@ bool TransactionEditor::enterTransactions(QString& newId, bool askForSchedule, b
         m_transactions.append(st);
       }
 
+      //    Save pricing information
+      QList<MyMoneySplit>::const_iterator it_t;
+      for (it_t = t.splits().constBegin(); it_t != t.splits().constEnd(); ++it_t) {
+        if (((*it_t).action() != "Buy") &&
+            ((*it_t).action() != "Sell") &&
+            ((*it_t).action() != "Reinvest")) {
+          continue;
+        }
+        QString id = (*it_t).accountId();
+        MyMoneyAccount acc = file->account(id);
+        MyMoneySecurity sec = file->security(acc.currencyId());
+        MyMoneyPrice price(acc.currencyId(),
+                           sec.tradingCurrency(),
+                           t.postDate(),
+                           (*it_t).price(), "Transaction");
+        file->addPrice(price);
+        break;
+      }
+
       ft.commit();
 
       // now analyze the balances and spit out warnings to the user
@@ -643,25 +662,25 @@ bool TransactionEditor::enterTransactions(QString& newId, bool askForSchedule, b
           key = "minBalanceEarly";
           if (!acc.value(key).isEmpty()) {
             if (minBalanceEarly[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the warning balance of %2.", acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the warning balance of %2.", acc.name(), MyMoneyUtils::formatMoney(MyMoneyMoney(acc.value(key)), acc, sec)));
             }
           }
           key = "minBalanceAbsolute";
           if (!acc.value(key).isEmpty()) {
             if (minBalanceAbsolute[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the minimum balance of %2.", acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the minimum balance of %2.", acc.name(), MyMoneyUtils::formatMoney(MyMoneyMoney(acc.value(key)), acc, sec)));
             }
           }
           key = "maxCreditEarly";
           if (!acc.value(key).isEmpty()) {
             if (maxCreditEarly[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit warning limit of %2.", acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit warning limit of %2.", acc.name(), MyMoneyUtils::formatMoney(MyMoneyMoney(acc.value(key)), acc, sec)));
             }
           }
           key = "maxCreditAbsolute";
           if (!acc.value(key).isEmpty()) {
             if (maxCreditAbsolute[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit limit of %2.", acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit limit of %2.", acc.name(), MyMoneyUtils::formatMoney(MyMoneyMoney(acc.value(key)), acc, sec)));
             }
           }
 
@@ -688,7 +707,7 @@ void TransactionEditor::resizeForm(void)
   // force resizeing of the columns in the form
   KMyMoneyTransactionForm::TransactionForm* form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(m_regForm);
   if (form) {
-    QTimer::singleShot(0, form, SLOT(resize()));
+    QMetaObject::invokeMethod(form, "resize", Qt::QueuedConnection, QGenericReturnArgument(), Q_ARG(int, ValueColumn1));
   }
 }
 
@@ -716,26 +735,26 @@ void StdTransactionEditor::createEditWidgets(void)
     account->setClickMessage(i18n("Account"));
     account->setObjectName(QLatin1String("Account"));
     m_editWidgets["account"] = account;
-    connect(account, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-    connect(account, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateAccount(const QString&)));
+    connect(account, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateButtonState()));
+    connect(account, SIGNAL(itemSelected(QString)), this, SLOT(slotUpdateAccount(QString)));
   }
 
   KMyMoneyPayeeCombo* payee = new KMyMoneyPayeeCombo;
   payee->setClickMessage(i18n("Payer/Receiver"));
   payee->setObjectName(QLatin1String("Payee"));
   m_editWidgets["payee"] = payee;
-  connect(payee, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(payee, SIGNAL(createItem(const QString&, QString&)), this, SIGNAL(createPayee(const QString&, QString&)));
+  connect(payee, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateButtonState()));
+  connect(payee, SIGNAL(createItem(QString,QString&)), this, SIGNAL(createPayee(QString,QString&)));
   connect(payee, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
-  connect(payee, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdatePayee(const QString&)));
+  connect(payee, SIGNAL(itemSelected(QString)), this, SLOT(slotUpdatePayee(QString)));
 
   KMyMoneyCategory* category = new KMyMoneyCategory(0, true);
   category->setClickMessage(i18n("Category/Account"));
   category->setObjectName(QLatin1String("Category/Account"));
   m_editWidgets["category"] = category;
-  connect(category, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateCategory(const QString&)));
-  connect(category, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(category, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateCategory(const QString&, QString&)));
+  connect(category, SIGNAL(itemSelected(QString)), this, SLOT(slotUpdateCategory(QString)));
+  connect(category, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateButtonState()));
+  connect(category, SIGNAL(createItem(QString,QString&)), this, SLOT(slotCreateCategory(QString,QString&)));
   connect(category, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
   connect(category->splitButton(), SIGNAL(clicked()), this, SLOT(slotEditSplits()));
   // initially disable the split button since we don't have an account set
@@ -745,6 +764,7 @@ void StdTransactionEditor::createEditWidgets(void)
   KTextEdit* memo = new KTextEdit;
   memo->setObjectName(QLatin1String("Memo"));
   memo->setTabChangesFocus(true);
+  connect(memo, SIGNAL(textChanged()), this, SLOT(slotUpdateButtonState()));
   m_editWidgets["memo"] = memo;
 
   bool showNumberField = true;
@@ -773,7 +793,7 @@ void StdTransactionEditor::createEditWidgets(void)
     number->setClickMessage(i18n("Number"));
     number->setObjectName(QLatin1String("Number"));
     m_editWidgets["number"] = number;
-    connect(number, SIGNAL(lineChanged(const QString&)), this, SLOT(slotNumberChanged(const QString&)));
+    connect(number, SIGNAL(lineChanged(QString)), this, SLOT(slotNumberChanged(QString)));
     // number->installEventFilter(this);
   }
 
@@ -781,28 +801,28 @@ void StdTransactionEditor::createEditWidgets(void)
   m_editWidgets["postdate"] = postDate;
   postDate->setObjectName(QLatin1String("PostDate"));
   postDate->setDate(QDate());
-  connect(postDate, SIGNAL(dateChanged(const QDate&)), this, SLOT(slotUpdateButtonState()));
+  connect(postDate, SIGNAL(dateChanged(QDate)), this, SLOT(slotUpdateButtonState()));
 
   kMyMoneyEdit* value = new kMyMoneyEdit;
   m_editWidgets["amount"] = value;
   value->setObjectName(QLatin1String("Amount"));
   value->setResetButtonVisible(false);
-  connect(value, SIGNAL(valueChanged(const QString&)), this, SLOT(slotUpdateAmount(const QString&)));
-  connect(value, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
+  connect(value, SIGNAL(valueChanged(QString)), this, SLOT(slotUpdateAmount(QString)));
+  connect(value, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateButtonState()));
 
   value = new kMyMoneyEdit;
   m_editWidgets["payment"] = value;
   value->setObjectName(QLatin1String("Payment"));
   value->setResetButtonVisible(false);
-  connect(value, SIGNAL(valueChanged(const QString&)), this, SLOT(slotUpdatePayment(const QString&)));
-  connect(value, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
+  connect(value, SIGNAL(valueChanged(QString)), this, SLOT(slotUpdatePayment(QString)));
+  connect(value, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateButtonState()));
 
   value = new kMyMoneyEdit;
   m_editWidgets["deposit"] = value;
   value->setObjectName(QLatin1String("Deposit"));
   value->setResetButtonVisible(false);
-  connect(value, SIGNAL(valueChanged(const QString&)), this, SLOT(slotUpdateDeposit(const QString&)));
-  connect(value, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
+  connect(value, SIGNAL(valueChanged(QString)), this, SLOT(slotUpdateDeposit(QString)));
+  connect(value, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateButtonState()));
 
   KMyMoneyCashFlowCombo* cashflow = new KMyMoneyCashFlowCombo(0, m_account.accountGroup());
   m_editWidgets["cashflow"] = cashflow;
@@ -813,7 +833,7 @@ void StdTransactionEditor::createEditWidgets(void)
   KMyMoneyReconcileCombo* reconcile = new KMyMoneyReconcileCombo;
   m_editWidgets["status"] = reconcile;
   reconcile->setObjectName(QLatin1String("Reconcile"));
-  connect(reconcile, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateButtonState()));
+  connect(reconcile, SIGNAL(itemSelected(QString)), this, SLOT(slotUpdateButtonState()));
 
   KMyMoneyRegister::QWidgetContainer::iterator it_w;
   for (it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
@@ -856,6 +876,7 @@ void StdTransactionEditor::createEditWidgets(void)
     tabbar->setObjectName(QLatin1String("TabBar"));
     tabbar->copyTabs(form->tabBar());
     connect(tabbar, SIGNAL(tabCurrentChanged(int)), this, SLOT(slotUpdateAction(int)));
+    connect(tabbar, SIGNAL(tabCurrentChanged(int)), this, SIGNAL(operationTypeChanged(int)));
   }
 
   setupPrecision();
@@ -949,10 +970,11 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
 
     if ((w = haveWidget("number")) != 0) {
       dynamic_cast<kMyMoneyLineEdit*>(w)->loadText(m_split.number());
-      if (m_transaction.id().isEmpty()                           // new transaction
-          && dynamic_cast<kMyMoneyLineEdit*>(w)->text().isEmpty()    // no number filled in
-          && m_account.accountType() == MyMoneyAccount::Checkings    // checkings account
-          && KMyMoneyGlobalSettings::autoIncCheckNumber()) {         // and auto inc number turned on?
+      if (m_transaction.id().isEmpty()                              // new transaction
+          && dynamic_cast<kMyMoneyLineEdit*>(w)->text().isEmpty()   // no number filled in
+          && m_account.accountType() == MyMoneyAccount::Checkings   // checkings account
+          && KMyMoneyGlobalSettings::autoIncCheckNumber()           // and auto inc number turned on?
+          && action != KMyMoneyRegister::ActionDeposit) {           // only transfers or withdrawals
         assignNextNumber();
       }
     }
@@ -1448,10 +1470,18 @@ void StdTransactionEditor::slotUpdateCategory(const QString& id)
       if (acc.isAssetLiability()
           || acc.accountGroup() == MyMoneyAccount::Equity) {
         if (tabbar) {
+          tabbar->setCurrentIndex(KMyMoneyRegister::ActionTransfer);
           tabbar->setTabEnabled(KMyMoneyRegister::ActionDeposit, false);
           tabbar->setTabEnabled(KMyMoneyRegister::ActionWithdrawal, false);
         }
-        if (val.isNegative())
+        if (val.isZero()) {
+          KMyMoneyCashFlowCombo* cashflow = dynamic_cast<KMyMoneyCashFlowCombo*>(m_editWidgets["cashflow"]);
+          if (cashflow && (cashflow->direction() == KMyMoneyRegister::Deposit)) {
+            categoryLabel->setText(i18n("Transfer from"));
+          } else {
+            categoryLabel->setText(i18n("Transfer to"));
+          }
+        } else if (val.isNegative())
           categoryLabel->setText(i18n("Transfer from"));
         else
           categoryLabel->setText(i18n("Transfer to"));
@@ -1741,6 +1771,7 @@ bool StdTransactionEditor::isComplete(QString& reason) const
     kMyMoneyEdit* amount = dynamic_cast<kMyMoneyEdit*>(*it_w);
     KMyMoneyReconcileCombo* reconcile = dynamic_cast<KMyMoneyReconcileCombo*>(*it_w);
     KMyMoneyCashFlowCombo* cashflow = dynamic_cast<KMyMoneyCashFlowCombo*>(*it_w);
+    KTextEdit* memo = dynamic_cast<KTextEdit*>(*it_w);
 
     if (payee && !(payee->currentText().isEmpty()))
       break;
@@ -1751,13 +1782,19 @@ bool StdTransactionEditor::isComplete(QString& reason) const
     if (amount && !(amount->value().isZero()))
       break;
 
-    // the following two widgets are only checked if we are editing multiple transactions
+    // the following widgets are only checked if we are editing multiple transactions
     if (isMultiSelection()) {
       if (reconcile && reconcile->state() != MyMoneySplit::Unknown)
         break;
 
       if (cashflow && cashflow->direction() != KMyMoneyRegister::Unknown)
         break;
+
+      if (postDate->date().isValid() && (postDate->date() >= m_account.openingDate()))
+        break;
+
+      if (memo && !memo->toPlainText().isEmpty())
+        break;
     }
   }
   return it_w != m_editWidgets.end();
@@ -1859,7 +1896,7 @@ int StdTransactionEditor::slotEditSplits(void)
                                  m_priceInfo,
                                  m_regForm);
       connect(dlg, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
-      connect(dlg, SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), this, SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)));
+      connect(dlg, SIGNAL(createCategory(MyMoneyAccount&,MyMoneyAccount)), this, SIGNAL(createCategory(MyMoneyAccount&,MyMoneyAccount)));
 
       if ((rc = dlg->exec()) == KDialog::Accepted) {
         m_transaction = dlg->transaction();
