@@ -638,6 +638,13 @@ protected:
     */
   void markTransaction(MyMoneySplit::reconcileFlagE flag);
 
+  /**
+    * This method allows to skip the next scheduled transaction of
+    * the given schedule @a s.
+    *
+    */
+  void skipSchedule(MyMoneySchedule& s);
+
   /**
     * This method allows to enter the next scheduled transaction of
     * the given schedule @a s. In case @a extendedKeys is @a true,
@@ -1070,18 +1077,19 @@ private:
     */
   void doDeleteTransactions(void);
 
-  /**
-    * Exchanges all references in transaction @a _t to account @a fromId
-    * into references to account @a toId. Returns @a true if at least
-    * one split has been changed, @a false otherwise.
-    */
-  bool exchangeAccountInTransaction(MyMoneyTransaction& _t, const QString& fromId, const QString& toId);
-
   /**
     * Re-implemented from IMyMoneyProcessingCalendar
     */
   bool isProcessingDate(const QDate& date) const;
 
+  /**
+    * Depending on the setting of AutoSaveOnQuit, this method
+    * asks the user to save the file or not.
+    *
+    * @returns see return values of KMessageBox::warningYesNoCancel()
+    */
+  int askSaveOnClose(void);
+
 signals:
   /**
     * This signal is emitted when a new file is loaded. In the case file
