@@ -34,6 +34,7 @@ protected:
   MyMoneyAccount  m_inv;
 
 private slots:
+  void initTestCase();
   void init();
   void cleanup();
   void testEmptyConstructor();
@@ -71,13 +72,35 @@ private slots:
   void testHasAccount();
   void testAddEquityAccount();
   void testReparentEquity();
-  void testReparentEquity(QList<MyMoneyAccount::accountTypeE>& list, MyMoneyAccount& parent);
   void testBaseCurrency();
   void testOpeningBalanceNoBase();
   void testOpeningBalance();
+  void testAddPrice();
+  void testRemovePrice();
+  void testAddAccountMissingCurrency();
+  void testAddTransactionToClosedAccount();
+  void testRemoveTransactionFromClosedAccount();
+  void testModifyTransactionInClosedAccount();
+  void testStorageId();
+
+private slots:
+  void objectAdded(MyMoneyFile::notificationObjectT type, const MyMoneyObject * const obj);
+  void objectModified(MyMoneyFile::notificationObjectT type, const MyMoneyObject * const obj);
+  void objectRemoved(MyMoneyFile::notificationObjectT type, const QString& id);
+  void balanceChanged(const MyMoneyAccount& account);
+  void valueChanged(const MyMoneyAccount& account);
 
 private:
   void testRemoveStdAccount(const MyMoneyAccount& acc);
+  void testReparentEquity(QList<MyMoneyAccount::accountTypeE>& list, MyMoneyAccount& parent);
+  void clearObjectLists(void);
+
+private:
+  QStringList m_objectsAdded;
+  QStringList m_objectsModified;
+  QStringList m_objectsRemoved;
+  QStringList m_balanceChanged;
+  QStringList m_valueChanged;
 };
 
 #endif
