@@ -510,6 +510,12 @@ void PivotTable::calculateColumnHeadings(void)
 
   int columnpitch = m_config_f.columnPitch();
 
+  if (columnpitch == 0) {
+    // output the warning but don't crash by dividing with 0
+    qWarning("PivotTable::calculateColumnHeadings() Invalid column pitch");
+    return;
+  }
+
   // if this is a days-based report
   if (m_config_f.isColumnsAreDays()) {
     if (columnpitch == 1) {
@@ -964,7 +970,7 @@ void PivotTable::convertToBaseCurrency(void)
           QDate valuedate = columnDate(column);
 
           //get base price for that date
-          MyMoneyMoney conversionfactor = it_row.key().baseCurrencyPrice(valuedate);
+          MyMoneyMoney conversionfactor = it_row.key().baseCurrencyPrice(valuedate, m_config_f.isSkippingZero());
 
           for (int i = 0; i < m_rowTypeList.size(); ++i) {
             if (m_rowTypeList[i] != eAverage) {
@@ -1009,7 +1015,7 @@ void PivotTable::convertToDeepCurrency(void)
           QDate valuedate = columnDate(column);
 
           //get conversion factor for the account and date
-          MyMoneyMoney conversionfactor = it_row.key().deepCurrencyPrice(valuedate);
+          MyMoneyMoney conversionfactor = it_row.key().deepCurrencyPrice(valuedate, m_config_f.isSkippingZero());
 
           //use the fraction relevant to the account at hand
           int fraction = it_row.key().currency().smallestAccountFraction();
@@ -1940,7 +1946,12 @@ void PivotTable::calculateForecast(void)
   }
 
   //run forecast
-  forecast.doForecast();
+  if (m_config_f.rowType() == MyMoneyReport::eAssetLiability) { //asset and liability
+    forecast.doForecast();
+  } else { //income and expenses
+    MyMoneyBudget budget;
+    forecast.createBudget(budget, m_beginDate.addYears(-1), m_beginDate.addDays(-1), m_beginDate, m_endDate, false);
+  }
 
   //go through the data and add forecast
   PivotGrid::iterator it_outergroup = m_grid.begin();
