@@ -108,8 +108,6 @@ KBudgetListItem::KBudgetListItem(QTreeWidget *parent, const MyMoneyBudget& budge
   setText(0, budget.name());
   setText(1, QString("%1").arg(budget.budgetStart().year()));
   setFlags(flags() | Qt::ItemIsEditable);
-  // allow in column rename
-  //setRenameEnabled(0, true);
 }
 
 KBudgetListItem::~KBudgetListItem()
@@ -134,6 +132,8 @@ BudgetAccountsProxyModel::BudgetAccountsProxyModel(QObject *parent/* = 0*/) :
   */
 QVariant BudgetAccountsProxyModel::data(const QModelIndex &index, int role) const
 {
+  if (!MyMoneyFile::instance()->storageAttached())
+    return QVariant();
   QModelIndex normalizedIndex = BudgetAccountsProxyModel::index(index.row(), 0, index.parent());
   if (role == AccountsModel::AccountBalanceRole ||
       role == AccountsModel::AccountBalanceDisplayRole ||
@@ -149,14 +149,14 @@ QVariant BudgetAccountsProxyModel::data(const QModelIndex &index, int role) cons
           return QVariant::fromValue(balance);
         case AccountsModel::AccountBalanceDisplayRole:
           if (MyMoneyFile::instance()->security(account.currencyId()) != MyMoneyFile::instance()->baseCurrency()) {
-            return balance.formatMoney(MyMoneyFile::instance()->security(account.currencyId()));
+            return MyMoneyUtils::formatMoney(balance, MyMoneyFile::instance()->security(account.currencyId()));
           } else {
             return QVariant();
           }
         case AccountsModel::AccountValueRole:
           return QVariant::fromValue(value);
         case AccountsModel::AccountValueDisplayRole:
-          return value.formatMoney(MyMoneyFile::instance()->baseCurrency());
+          return MyMoneyUtils::formatMoney(value, MyMoneyFile::instance()->baseCurrency());
       }
     }
   }
@@ -167,7 +167,7 @@ QVariant BudgetAccountsProxyModel::data(const QModelIndex &index, int role) cons
       case AccountsModel::AccountTotalValueRole:
         return QVariant::fromValue(totalValue);
       case AccountsModel::AccountTotalValueDisplayRole:
-        return totalValue.formatMoney(MyMoneyFile::instance()->baseCurrency());
+        return MyMoneyUtils::formatMoney(totalValue, MyMoneyFile::instance()->baseCurrency());
     }
   }
   return AccountsViewFilterProxyModel::data(index, role);
@@ -285,8 +285,7 @@ MyMoneyMoney BudgetAccountsProxyModel::computeTotalValue(const QModelIndex &sour
 KBudgetView::KBudgetView(QWidget *parent) :
     QWidget(parent),
     m_needReload(false),
-    m_inSelection(false),
-    m_budgetInEditing(false)
+    m_inSelection(false)
 {
   setupUi(this);
 
@@ -349,20 +348,20 @@ KBudgetView::KBudgetView(QWidget *parent) :
   m_accountTree->setModel(m_filterProxyModel);
 
   // let the model know if the item is expanded or collapsed
-  connect(m_accountTree, SIGNAL(collapsed(const QModelIndex &)), m_filterProxyModel, SLOT(collapsed(const QModelIndex &)));
-  connect(m_accountTree, SIGNAL(expanded(const QModelIndex &)), m_filterProxyModel, SLOT(expanded(const QModelIndex &)));
+  connect(m_accountTree, SIGNAL(collapsed(QModelIndex)), m_filterProxyModel, SLOT(collapsed(QModelIndex)));
+  connect(m_accountTree, SIGNAL(expanded(QModelIndex)), m_filterProxyModel, SLOT(expanded(QModelIndex)));
 
-  connect(m_accountTree, SIGNAL(selectObject(const MyMoneyObject&)), this, SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_accountTree, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_accountTree, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectInstitution(const MyMoneyObject&)));
-  connect(m_accountTree, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectInvestment(const MyMoneyObject&)));
-  connect(m_accountTree, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
-  connect(m_accountTree, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotAccountOpen(const MyMoneyObject&)));
+  connect(m_accountTree, SIGNAL(selectObject(MyMoneyObject)), this, SLOT(slotSelectAccount(MyMoneyObject)));
+  connect(m_accountTree, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectAccount(MyMoneyObject)));
+  connect(m_accountTree, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectInstitution(MyMoneyObject)));
+  connect(m_accountTree, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectInvestment(MyMoneyObject)));
+  connect(m_accountTree, SIGNAL(openContextMenu(MyMoneyObject)), kmymoney, SLOT(slotShowAccountContextMenu(MyMoneyObject)));
+  connect(m_accountTree, SIGNAL(openObject(MyMoneyObject)), kmymoney, SLOT(slotAccountOpen(MyMoneyObject)));
 
-  connect(m_budgetList, SIGNAL(customContextMenuRequested(const QPoint&)),
-          this, SLOT(slotOpenContextMenu(const QPoint&)));
-  connect(m_budgetList, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotRenameBudget(QTreeWidgetItem*)));
-  connect(m_budgetList->selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)), this, SLOT(slotSelectBudget()));
+  connect(m_budgetList, SIGNAL(customContextMenuRequested(QPoint)),
+          this, SLOT(slotOpenContextMenu(QPoint)));
+  connect(m_budgetList->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(slotSelectBudget()));
+  connect(m_budgetList, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotItemChanged(QTreeWidgetItem*,int)));
 
   connect(m_cbBudgetSubaccounts, SIGNAL(clicked()), this, SLOT(cb_includesSubaccounts_clicked()));
 
@@ -390,7 +389,7 @@ KBudgetView::KBudgetView(QWidget *parent) :
   connect(m_expandButton, SIGNAL(clicked()), m_accountTree, SLOT(expandAll()));
   connect(m_accountTree, SIGNAL(expandedAll()), m_filterProxyModel, SLOT(expandAll()));
 
-  connect(m_searchWidget, SIGNAL(textChanged(const QString &)), m_filterProxyModel, SLOT(setFilterFixedString(const QString &)));
+  connect(m_searchWidget, SIGNAL(textChanged(QString)), m_filterProxyModel, SLOT(setFilterFixedString(QString)));
 
   // setup initial state
   m_newButton->setEnabled(kmymoney->action("budget_new")->isEnabled());
@@ -400,50 +399,28 @@ KBudgetView::KBudgetView(QWidget *parent) :
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotRefreshView()));
 
   KConfigGroup grp = KGlobal::config()->group("Last Use Settings");
-  QList<int> sizes = grp.readEntry("KBudgetViewSplitterSize", QList<int>());
-  if (sizes.size() == 2) {
-    if ((sizes[0] == 0) || (sizes[1] == 0)) {
-      sizes[0] = 1;
-      sizes[1] = 3;
-    }
-    m_splitter->setSizes(sizes);
-  }
+  m_splitter->restoreState(grp.readEntry("KBudgetViewSplitterSize", QByteArray()));
+  m_splitter->setChildrenCollapsible(false);
 }
 
 KBudgetView::~KBudgetView()
 {
   // remember the splitter settings for startup
   KConfigGroup grp = KGlobal::config()->group("Last Use Settings");
-  grp.writeEntry("KBudgetViewSplitterSize", m_splitter->sizes());
+  grp.writeEntry("KBudgetViewSplitterSize", m_splitter->saveState());
+  grp.sync();
 }
 
 void KBudgetView::showEvent(QShowEvent * event)
 {
-  QTimer::singleShot(50, this, SLOT(slotRearrange()));
+  emit aboutToShow();
+
   if (m_needReload) {
     slotRefreshView();
   }
   QWidget::showEvent(event);
 }
 
-void KBudgetView::slotRearrange(void)
-{
-  resizeEvent(0);
-}
-
-void KBudgetView::resizeEvent(QResizeEvent* ev)
-{
-  // resize the register
-  QWidget::resizeEvent(ev);
-}
-
-void KBudgetView::slotReloadView(void)
-{
-  ::timetrace("Start KBudgetView::slotReloadView");
-  slotRearrange();
-  ::timetrace("Done KBudgetView::slotReloadView");
-}
-
 void KBudgetView::loadBudgets(void)
 {
   ::timetrace("Start KBudgetView::loadBudgets");
@@ -455,7 +432,6 @@ void KBudgetView::loadBudgets(void)
 
   // clear the budget list
   m_budgetList->clear();
-  m_budgetValue->clear();
 
   // add the correct years to the drop down list
   QDate date = QDate::currentDate();
@@ -498,6 +474,7 @@ void KBudgetView::loadBudgets(void)
   // make sure the world around us knows what we have selected
   slotSelectBudget();
 
+
   ::timetrace("End KBudgetView::loadBudgets");
 }
 
@@ -577,7 +554,6 @@ void KBudgetView::slotSelectBudget(void)
 {
   askSave();
   KBudgetListItem* item;
-  m_budgetInEditing = false;
 
   QTreeWidgetItemIterator widgetIt = QTreeWidgetItemIterator(m_budgetList);
   if (m_budget.id().isEmpty()) {
@@ -602,6 +578,13 @@ void KBudgetView::slotSelectBudget(void)
 
   slotRefreshHideUnusedButton();
   loadAccounts();
+  QModelIndex index = m_accountTree->currentIndex();
+  if (index.isValid()) {
+    MyMoneyAccount acc = m_accountTree->model()->data(index, AccountsModel::AccountRole).value<MyMoneyAccount>();
+    slotSelectAccount(acc);
+  } else {
+    m_budgetValue->clear();
+  }
 
   QList<MyMoneyBudget> budgetList;
   if (!m_budget.id().isEmpty())
@@ -641,7 +624,6 @@ void KBudgetView::slotOpenContextMenu(const QPoint& p)
 
 void KBudgetView::slotStartRename(void)
 {
-  m_budgetInEditing = true;
   QTreeWidgetItemIterator it_l(m_budgetList, QTreeWidgetItemIterator::Selected);
   QTreeWidgetItem* it_v;
   if ((it_v = *it_l) != 0) {
@@ -649,20 +631,16 @@ void KBudgetView::slotStartRename(void)
   }
 }
 
-// This variant is only called when a single budget is selected and renamed.
-void KBudgetView::slotRenameBudget(QTreeWidgetItem* p)
+void KBudgetView::slotItemChanged(QTreeWidgetItem* p, int col)
 {
-  KBudgetListItem *pBudget = dynamic_cast<KBudgetListItem*>(p);
-
-  //if there is no current item selected, exit
-  if (m_budgetInEditing == false || !m_budgetList->currentItem() || p != m_budgetList->currentItem())
+  // if we don't have an item or something changed in the year column
+  // we actually don't care about it
+  if (!p || col != 0)
     return;
 
-  m_budgetInEditing = false;
-
-  //kDebug() << "[KPayeesView::slotRenamePayee]";
-  // create a copy of the new name without appended whitespaces
-  QString new_name = p->text(0);
+  KBudgetListItem *pBudget = dynamic_cast<KBudgetListItem*>(p);
+  // create a copy of the new name without leading and trailing whitespaces
+  QString new_name = p->text(0).trimmed();
 
   if (pBudget->budget().name() != new_name) {
     MyMoneyFileTransaction ft;
@@ -699,7 +677,7 @@ void KBudgetView::slotRenameBudget(QTreeWidgetItem* p)
 
     } catch (MyMoneyException *e) {
       KMessageBox::detailedSorry(0, i18n("Unable to modify budget"),
-                                 (e->what() + ' ' + i18n("thrown in") + ' ' + e->file() + ":%1").arg(e->line()));
+                                 i18n("%1 thrown in %2:%3", e->what(), e->file(), e->line()));
       delete e;
     }
   } else {
@@ -854,9 +832,17 @@ void KBudgetView::slotResetBudget(void)
   try {
     m_budget = MyMoneyFile::instance()->budget(m_budget.id());
     loadAccounts();
+    QModelIndex index = m_accountTree->currentIndex();
+    if (index.isValid()) {
+      MyMoneyAccount acc = m_accountTree->model()->data(index, AccountsModel::AccountRole).value<MyMoneyAccount>();
+      slotSelectAccount(acc);
+    } else {
+      m_budgetValue->clear();
+    }
+
   } catch (MyMoneyException *e) {
     KMessageBox::detailedSorry(0, i18n("Unable to reset budget"),
-                               (e->what() + ' ' + i18n("thrown in") + ' ' + e->file() + ":%1").arg(e->line()));
+                               i18n("%1 thrown in %2:%3", e->what(), e->file(), e->line()));
     delete e;
   }
 }
@@ -870,7 +856,7 @@ void KBudgetView::slotUpdateBudget(void)
     slotRefreshHideUnusedButton();
   } catch (MyMoneyException *e) {
     KMessageBox::detailedSorry(0, i18n("Unable to modify budget"),
-                               (e->what() + ' ' + i18n("thrown in") + ' ' + e->file() + ":%1").arg(e->line()));
+                               i18n("%1 thrown in %2:%3", e->what(), e->file(), e->line()));
     delete e;
   }
 }
