@@ -89,12 +89,12 @@ KInvestmentView::KInvestmentView(QWidget *parent) :
 
   connect(m_tab, SIGNAL(currentChanged(QWidget*)), this, SLOT(slotTabCurrentChanged(QWidget*)));
 
-  connect(m_investmentsList, SIGNAL(customContextMenuRequested(const QPoint&)),
-          this, SLOT(slotInvestmentContextMenu(const QPoint&)));
+  connect(m_investmentsList, SIGNAL(customContextMenuRequested(QPoint)),
+          this, SLOT(slotInvestmentContextMenu(QPoint)));
   connect(m_investmentsList, SIGNAL(itemSelectionChanged()), this, SLOT(slotInvestmentSelectionChanged()));
-  connect(m_accountComboBox, SIGNAL(accountSelected(const QString&)),
-          this, SLOT(slotSelectAccount(const QString&)));
-  connect(m_investmentsList, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), kmymoney->action("investment_edit"), SLOT(trigger()));
+  connect(m_accountComboBox, SIGNAL(accountSelected(QString)),
+          this, SLOT(slotSelectAccount(QString)));
+  connect(m_investmentsList, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), kmymoney->action("investment_edit"), SLOT(trigger()));
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadView()));
 
   // create the searchline widget
@@ -414,6 +414,8 @@ void KInvestmentView::loadInvestmentItem(const MyMoneyAccount& account)
 
 void KInvestmentView::showEvent(QShowEvent* event)
 {
+  emit aboutToShow();
+
   /*if (d->m_needReload) {
     loadInvestmentTab();
     d->m_needReload = false;
@@ -423,9 +425,10 @@ void KInvestmentView::showEvent(QShowEvent* event)
     emit accountSelected(d->m_account);
   }*/
 
+  slotTabCurrentChanged(m_tab->currentWidget());
+
   // don't forget base class implementation
   QWidget::showEvent(event);
-  slotTabCurrentChanged(m_tab->currentWidget());
 }
 
 void KInvestmentView::loadSecuritiesList(void)
