@@ -137,45 +137,48 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
 
   m_model = new KPageWidgetModel(parent);
 
-  connect(kmymoney, SIGNAL(fileLoaded(const KUrl&)), this, SLOT(slotRefreshViews()));
+  connect(kmymoney, SIGNAL(fileLoaded(KUrl)), this, SLOT(slotRefreshViews()));
 
   // let the accounts model know which account is being currently reconciled
-  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), Models::instance()->accountsModel(), SLOT(slotReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
+  connect(this, SIGNAL(reconciliationStarts(MyMoneyAccount,QDate,MyMoneyMoney)), Models::instance()->accountsModel(), SLOT(slotReconcileAccount(MyMoneyAccount,QDate,MyMoneyMoney)));
 
   // Page 0
   m_homeView = new KHomeView();
   m_homeViewFrame = m_model->addPage(m_homeView, i18n("Home"));
   m_homeViewFrame->setIcon(KIcon("go-home"));
-  connect(m_homeView, SIGNAL(ledgerSelected(const QString&, const QString&)),
-          this, SLOT(slotLedgerSelected(const QString&, const QString&)));
-  connect(m_homeView, SIGNAL(scheduleSelected(const QString&)),
-          this, SLOT(slotScheduleSelected(const QString&)));
-  connect(m_homeView, SIGNAL(reportSelected(const QString&)),
-          this, SLOT(slotShowReport(const QString&)));
+  connect(m_homeView, SIGNAL(ledgerSelected(QString,QString)),
+          this, SLOT(slotLedgerSelected(QString,QString)));
+  connect(m_homeView, SIGNAL(scheduleSelected(QString)),
+          this, SLOT(slotScheduleSelected(QString)));
+  connect(m_homeView, SIGNAL(reportSelected(QString)),
+          this, SLOT(slotShowReport(QString)));
+  connect(m_homeView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 1
   m_institutionsView = new KInstitutionsView();
   m_institutionsViewFrame = m_model->addPage(m_institutionsView, i18n("Institutions"));
   m_institutionsViewFrame->setIcon(KIcon("institution"));
 
-  connect(m_institutionsView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_institutionsView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectInstitution(const MyMoneyObject&)));
-  connect(m_institutionsView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
-  connect(m_institutionsView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowInstitutionContextMenu(const MyMoneyObject&)));
-  connect(m_institutionsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotInstitutionEdit(const MyMoneyObject&)));
-  connect(m_institutionsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotAccountOpen(const MyMoneyObject&)));
+  connect(m_institutionsView, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectAccount(MyMoneyObject)));
+  connect(m_institutionsView, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectInstitution(MyMoneyObject)));
+  connect(m_institutionsView, SIGNAL(openContextMenu(MyMoneyObject)), kmymoney, SLOT(slotShowAccountContextMenu(MyMoneyObject)));
+  connect(m_institutionsView, SIGNAL(openContextMenu(MyMoneyObject)), kmymoney, SLOT(slotShowInstitutionContextMenu(MyMoneyObject)));
+  connect(m_institutionsView, SIGNAL(openObject(MyMoneyObject)), kmymoney, SLOT(slotInstitutionEdit(MyMoneyObject)));
+  connect(m_institutionsView, SIGNAL(openObject(MyMoneyObject)), kmymoney, SLOT(slotAccountOpen(MyMoneyObject)));
+  connect(m_institutionsView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 2
   m_accountsView = new KAccountsView();
   m_accountsViewFrame = m_model->addPage(m_accountsView, i18n("Accounts"));
   m_accountsViewFrame->setIcon(KIcon("account")); //krazy:exclude=iconnames
 
-  connect(m_accountsView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_accountsView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectInstitution(const MyMoneyObject&)));
-  connect(m_accountsView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectInvestment(const MyMoneyObject&)));
-  connect(m_accountsView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
-  connect(m_accountsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotAccountOpen(const MyMoneyObject&)));
-  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), m_accountsView, SLOT(slotReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
+  connect(m_accountsView, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectAccount(MyMoneyObject)));
+  connect(m_accountsView, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectInstitution(MyMoneyObject)));
+  connect(m_accountsView, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectInvestment(MyMoneyObject)));
+  connect(m_accountsView, SIGNAL(openContextMenu(MyMoneyObject)), kmymoney, SLOT(slotShowAccountContextMenu(MyMoneyObject)));
+  connect(m_accountsView, SIGNAL(openObject(MyMoneyObject)), kmymoney, SLOT(slotAccountOpen(MyMoneyObject)));
+  connect(this, SIGNAL(reconciliationStarts(MyMoneyAccount,QDate,MyMoneyMoney)), m_accountsView, SLOT(slotReconcileAccount(MyMoneyAccount,QDate,MyMoneyMoney)));
+  connect(m_accountsView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 3
   m_scheduledView = new KScheduledView();
@@ -187,50 +190,54 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
 #endif
   m_scheduleViewFrame->setIcon(KIcon("view-pim-calendar"));
 
-  connect(kmymoney, SIGNAL(fileLoaded(const KUrl&)), m_scheduledView, SLOT(slotReloadView()));
-  connect(m_scheduledView, SIGNAL(scheduleSelected(const MyMoneySchedule&)), kmymoney, SLOT(slotSelectSchedule(const MyMoneySchedule&)));
+  connect(m_scheduledView, SIGNAL(scheduleSelected(MyMoneySchedule)), kmymoney, SLOT(slotSelectSchedule(MyMoneySchedule)));
   connect(m_scheduledView, SIGNAL(openContextMenu()), kmymoney, SLOT(slotShowScheduleContextMenu()));
   connect(m_scheduledView, SIGNAL(enterSchedule()), kmymoney, SLOT(slotScheduleEnter()));
   connect(m_scheduledView, SIGNAL(skipSchedule()), kmymoney, SLOT(slotScheduleSkip()));
   connect(m_scheduledView, SIGNAL(editSchedule()), kmymoney, SLOT(slotScheduleEdit()));
+  connect(m_scheduledView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 4
   m_categoriesView = new KCategoriesView();
   m_categoriesViewFrame = m_model->addPage(m_categoriesView, i18n("Categories"));
   m_categoriesViewFrame->setIcon(KIcon("categories"));
 
-  connect(m_categoriesView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_categoriesView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectInstitution(const MyMoneyObject&)));
-  connect(m_categoriesView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
-  connect(m_categoriesView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotAccountOpen(const MyMoneyObject&)));
-  connect(m_categoriesView, SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&)), kmymoney, SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyAccount&)));
+  connect(m_categoriesView, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectAccount(MyMoneyObject)));
+  connect(m_categoriesView, SIGNAL(selectObject(MyMoneyObject)), kmymoney, SLOT(slotSelectInstitution(MyMoneyObject)));
+  connect(m_categoriesView, SIGNAL(openContextMenu(MyMoneyObject)), kmymoney, SLOT(slotShowAccountContextMenu(MyMoneyObject)));
+  connect(m_categoriesView, SIGNAL(openObject(MyMoneyObject)), kmymoney, SLOT(slotAccountOpen(MyMoneyObject)));
+  connect(m_categoriesView, SIGNAL(reparent(MyMoneyAccount,MyMoneyAccount)), kmymoney, SLOT(slotReparentAccount(MyMoneyAccount,MyMoneyAccount)));
+  connect(m_categoriesView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 5
   m_payeesView = new KPayeesView();
   m_payeesViewFrame = m_model->addPage(m_payeesView, i18n("Payees"));
   m_payeesViewFrame->setIcon(KIcon("system-users"));
 
-  connect(kmymoney, SIGNAL(payeeCreated(const QString&)), m_payeesView, SLOT(slotSelectPayeeAndTransaction(const QString&)));
+  connect(kmymoney, SIGNAL(payeeCreated(QString)), m_payeesView, SLOT(slotSelectPayeeAndTransaction(QString)));
   connect(kmymoney, SIGNAL(payeeRename()), m_payeesView, SLOT(slotRenameButtonCliked()));
-  connect(m_payeesView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowPayeeContextMenu()));
-  connect(m_payeesView, SIGNAL(selectObjects(const QList<MyMoneyPayee>&)), kmymoney, SLOT(slotSelectPayees(const QList<MyMoneyPayee>&)));
-  connect(m_payeesView, SIGNAL(transactionSelected(const QString&, const QString&)),
-          this, SLOT(slotLedgerSelected(const QString&, const QString&)));
+  connect(m_payeesView, SIGNAL(openContextMenu(MyMoneyObject)), kmymoney, SLOT(slotShowPayeeContextMenu()));
+  connect(m_payeesView, SIGNAL(selectObjects(QList<MyMoneyPayee>)), kmymoney, SLOT(slotSelectPayees(QList<MyMoneyPayee>)));
+  connect(m_payeesView, SIGNAL(transactionSelected(QString,QString)),
+          this, SLOT(slotLedgerSelected(QString,QString)));
+  connect(m_payeesView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
+
   // Page 6
   m_ledgerView = new KGlobalLedgerView();
   m_ledgerViewFrame = m_model->addPage(m_ledgerView, i18n("Ledgers"));
   m_ledgerViewFrame->setIcon(KIcon("ledger"));  //krazy:exclude=iconnames
 
-  connect(m_ledgerView, SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney, SLOT(slotSelectAccount(const MyMoneyObject&)));
+  connect(m_ledgerView, SIGNAL(accountSelected(MyMoneyObject)), kmymoney, SLOT(slotSelectAccount(MyMoneyObject)));
   connect(m_ledgerView, SIGNAL(openContextMenu()), kmymoney, SLOT(slotShowTransactionContextMenu()));
-  connect(m_ledgerView, SIGNAL(transactionsSelected(const KMyMoneyRegister::SelectedTransactions&)), kmymoney, SLOT(slotSelectTransactions(const KMyMoneyRegister::SelectedTransactions&)));
+  connect(m_ledgerView, SIGNAL(transactionsSelected(KMyMoneyRegister::SelectedTransactions)), kmymoney, SLOT(slotSelectTransactions(KMyMoneyRegister::SelectedTransactions)));
   connect(m_ledgerView, SIGNAL(newTransaction()), kmymoney, SLOT(slotTransactionsNew()));
   connect(m_ledgerView, SIGNAL(cancelOrEndEdit(bool&)), kmymoney, SLOT(slotTransactionsCancelOrEnter(bool&)));
   connect(m_ledgerView, SIGNAL(startEdit()), kmymoney, SLOT(slotTransactionsEdit()));
   connect(m_ledgerView, SIGNAL(endEdit()), kmymoney, SLOT(slotTransactionsEnter()));
   connect(m_ledgerView, SIGNAL(toggleReconciliationFlag()), kmymoney, SLOT(slotToggleReconciliationFlag()));
-  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), m_ledgerView, SLOT(slotSetReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
+  connect(this, SIGNAL(reconciliationStarts(MyMoneyAccount,QDate,MyMoneyMoney)), m_ledgerView, SLOT(slotSetReconcileAccount(MyMoneyAccount,QDate,MyMoneyMoney)));
   connect(kmymoney, SIGNAL(selectAllTransactions()), m_ledgerView, SLOT(slotSelectAllTransactions()));
+  connect(m_ledgerView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
 
   // Page 7
@@ -238,36 +245,41 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
   m_investmentViewFrame = m_model->addPage(m_investmentView, i18n("Investments"));
   m_investmentViewFrame->setIcon(KIcon("investment"));
 
-  connect(m_investmentView, SIGNAL(accountSelected(const QString&, const QString&)),
-          this, SLOT(slotLedgerSelected(const QString&, const QString&)));
-  connect(m_investmentView, SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney, SLOT(slotSelectAccount(const MyMoneyObject&)));
+  connect(m_investmentView, SIGNAL(accountSelected(QString,QString)),
+          this, SLOT(slotLedgerSelected(QString,QString)));
+  connect(m_investmentView, SIGNAL(accountSelected(MyMoneyObject)), kmymoney, SLOT(slotSelectAccount(MyMoneyObject)));
   connect(m_investmentView, SIGNAL(investmentRightMouseClick()), kmymoney, SLOT(slotShowInvestmentContextMenu()));
+  connect(m_investmentView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 8
   m_reportsView = new KReportsView();
   m_reportsViewFrame = m_model->addPage(m_reportsView, i18n("Reports"));
   m_reportsViewFrame->setIcon(KIcon("office-chart-tall-pie"));
+  connect(m_reportsView, SIGNAL(ledgerSelected(QString,QString)),
+          this, SLOT(slotLedgerSelected(QString,QString)));
+  connect(m_reportsView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 9
   m_budgetView = new KBudgetView();
   m_budgetViewFrame = m_model->addPage(m_budgetView, i18n("Budgets"));
   m_budgetViewFrame->setIcon(KIcon("budget"));
 
-  connect(kmymoney, SIGNAL(fileLoaded(const KUrl&)), m_budgetView, SLOT(slotRefreshView()));
-  connect(m_budgetView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowBudgetContextMenu()));
-  connect(m_budgetView, SIGNAL(selectObjects(const QList<MyMoneyBudget>&)), kmymoney, SLOT(slotSelectBudget(const QList<MyMoneyBudget>&)));
+  connect(m_budgetView, SIGNAL(openContextMenu(MyMoneyObject)), kmymoney, SLOT(slotShowBudgetContextMenu()));
+  connect(m_budgetView, SIGNAL(selectObjects(QList<MyMoneyBudget>)), kmymoney, SLOT(slotSelectBudget(QList<MyMoneyBudget>)));
   connect(kmymoney, SIGNAL(budgetRename()), m_budgetView, SLOT(slotStartRename()));
+  connect(m_budgetView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   // Page 10
   m_forecastView = new KForecastView();
   m_forecastViewFrame = m_model->addPage(m_forecastView, i18n("Forecast"));
   m_forecastViewFrame->setIcon(KIcon("forecast"));
+  connect(m_forecastView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   //set the model
   setModel(m_model);
 
   setCurrentPage(m_homeViewFrame);
-  connect(this, SIGNAL(currentPageChanged(const QModelIndex, const QModelIndex)), this, SLOT(slotCurrentPageChanged(const QModelIndex, const QModelIndex)));
+  connect(this, SIGNAL(currentPageChanged(QModelIndex,QModelIndex)), this, SLOT(slotCurrentPageChanged(QModelIndex,QModelIndex)));
 
   updateViewType();
 
@@ -301,8 +313,18 @@ void KMyMoneyView::updateViewType(void)
       faceType = KPageView::Tabbed;
       break;
   }
-  if (faceType != KMyMoneyView::faceType())
+  if (faceType != KMyMoneyView::faceType()) {
     setFaceType(faceType);
+    if (faceType == KPageView::Tree) {
+      QList<QTreeView *> views = findChildren<QTreeView*>();
+      foreach (QTreeView * view, views) {
+        if (view && (view->parent() == this)) {
+          view->setRootIsDecorated(false);
+          break;
+        }
+      }
+    }
+  }
 }
 
 bool KMyMoneyView::showPageHeader() const
@@ -430,6 +452,7 @@ void KMyMoneyView::newStorage(storageTypeE t)
     file->attachStorage(new MyMoneySeqAccessMgr);
   else
     file->attachStorage(new MyMoneyDatabaseMgr);
+
 }
 
 void KMyMoneyView::removeStorage(void)
@@ -548,6 +571,29 @@ void KMyMoneyView::closeFile(void)
   if (m_reportsView)
     m_reportsView->slotCloseAll();
 
+  // disconnect the signals
+  disconnect(MyMoneyFile::instance(), SIGNAL(objectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+             Models::instance()->accountsModel(), SLOT(slotObjectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(objectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+             Models::instance()->accountsModel(), SLOT(slotObjectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(objectRemoved(MyMoneyFile::notificationObjectT,QString)),
+             Models::instance()->accountsModel(), SLOT(slotObjectRemoved(MyMoneyFile::notificationObjectT,QString)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(balanceChanged(MyMoneyAccount)),
+             Models::instance()->accountsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(valueChanged(MyMoneyAccount)),
+             Models::instance()->accountsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
+
+  disconnect(MyMoneyFile::instance(), SIGNAL(objectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+             Models::instance()->institutionsModel(), SLOT(slotObjectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(objectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+             Models::instance()->institutionsModel(), SLOT(slotObjectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(objectRemoved(MyMoneyFile::notificationObjectT,QString)),
+             Models::instance()->institutionsModel(), SLOT(slotObjectRemoved(MyMoneyFile::notificationObjectT,QString)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(balanceChanged(MyMoneyAccount)),
+             Models::instance()->institutionsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
+  disconnect(MyMoneyFile::instance(), SIGNAL(valueChanged(MyMoneyAccount)),
+             Models::instance()->institutionsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
+
   // notify the models that the file is going to be closed (we should have something like dataChanged that reaches the models first)
   Models::instance()->fileClosed();
 
@@ -560,8 +606,6 @@ void KMyMoneyView::closeFile(void)
 
   emit kmmFilePlugin(postClose);
   m_fileOpen = false;
-
-  disconnect(MyMoneyFile::instance(), SIGNAL(dataChanged()), Models::instance(), SLOT(dataChanged()));
 }
 
 void KMyMoneyView::ungetString(QIODevice *qfile, char *buf, int len)
@@ -576,7 +620,6 @@ bool KMyMoneyView::readFile(const KUrl& url)
 {
   QString filename;
 
-//  newStorage();
   m_fileOpen = false;
   bool isEncrypted = false;
 
@@ -587,9 +630,10 @@ bool KMyMoneyView::readFile(const KUrl& url)
     return false;
   }
 
+  // disconnect the current storga manager from the engine
+  MyMoneyFile::instance()->detachStorage();
+
   if (url.protocol() == "sql") { // handle reading of database
-    //newStorage(Database);
-    MyMoneyFile::instance()->detachStorage();
     m_fileType = KmmDb;
     // get rid of the mode parameter which is now redundant
     KUrl newUrl(url);
@@ -599,7 +643,7 @@ bool KMyMoneyView::readFile(const KUrl& url)
     return (openDatabase(newUrl)); // on error, any message will have been displayed
   }
 
-  newStorage();
+  IMyMoneyStorage *storage = new MyMoneySeqAccessMgr;
 
   if (url.isLocalFile()) {
     filename = url.toLocalFile();
@@ -723,10 +767,13 @@ bool KMyMoneyView::readFile(const KUrl& url)
                   m_fileType = KmmXML;
                 } else if (gncexp.indexIn(txt) != -1) {
                   ::timetrace("is GNC format");
+                  MyMoneyFile::instance()->attachStorage(storage);
                   MyMoneyFileTransaction ft;
                   loadDefaultCurrencies(); // currency list required for gnc
                   loadAncientCurrencies(); // these too
                   ft.commit();
+                  MyMoneyFile::instance()->detachStorage(storage);
+
                   pReader = new MyMoneyGncReader;
                   m_fileType = GncXML;
                 }
@@ -735,7 +782,7 @@ bool KMyMoneyView::readFile(const KUrl& url)
             if (pReader) {
               pReader->setProgressCallback(&KMyMoneyView::progressCallback);
               ::timetrace("read data to memory");
-              pReader->readFile(qfile, dynamic_cast<IMyMoneySerialize*>(MyMoneyFile::instance()->storage()));
+              pReader->readFile(qfile, dynamic_cast<IMyMoneySerialize*>(storage));
               ::timetrace("done reading to memory");
             } else {
               if (m_fileType == KmmBinary) {
@@ -775,19 +822,26 @@ bool KMyMoneyView::readFile(const KUrl& url)
     rc = false;
   }
 
+  // things are finished, now we connect the storage to the engine
+  // which forces a reload of the cache in the engine with those
+  // objects that are cached
+  MyMoneyFile::instance()->attachStorage(storage);
+
   ::timetrace("done reading file");
   if (rc == false)
     return rc;
 
-  // make sure we setup the encryption key correctly
+  // encapsulate transactions to the engine to be able to commit/rollback
   MyMoneyFileTransaction ft;
+
+  // make sure we setup the encryption key correctly
   if (isEncrypted && MyMoneyFile::instance()->value("kmm-encryption-key").isEmpty()) {
     MyMoneyFile::instance()->setValue("kmm-encryption-key", KMyMoneyGlobalSettings::gpgRecipientList().join(","));
   }
 
   // make sure we setup the name of the base accounts in translated form
   try {
-    MyMoneyFile* file = MyMoneyFile::instance();
+    MyMoneyFile *file = MyMoneyFile::instance();
     checkAccountName(file->asset(), i18n("Asset"));
     checkAccountName(file->liability(), i18n("Liability"));
     checkAccountName(file->income(), i18n("Income"));
@@ -899,12 +953,26 @@ bool KMyMoneyView::initializeStorage()
 
   // make sure, we have a base currency and all accounts are
   // also assigned to a currency.
-  if (MyMoneyFile::instance()->baseCurrency().id().isEmpty()) {
+  QString baseId;
+  try {
+    baseId = MyMoneyFile::instance()->baseCurrency().id();
+  } catch (MyMoneyException *e) {
+    qDebug("%s", qPrintable(e->what()));
+    delete e;
+  }
+
+  if (baseId.isEmpty()) {
     // Stay in this endless loop until we have a base currency,
     // as without it the application does not work anymore.
-    while (MyMoneyFile::instance()->baseCurrency().id().isEmpty())
+    while (baseId.isEmpty()) {
       selectBaseCurrency();
-
+      try {
+        baseId = MyMoneyFile::instance()->baseCurrency().id();
+      } catch (MyMoneyException *e) {
+        qDebug("%s", qPrintable(e->what()));
+        delete e;
+      }
+    }
   } else {
     // in some odd intermediate cases there could be files out there
     // that have a base currency set, but still have accounts that
@@ -958,6 +1026,11 @@ bool KMyMoneyView::initializeStorage()
             s->setFileFixVersion(3);
             break;
 
+          case 3:
+            fixFile_3();
+            s->setFileFixVersion(4);
+            break;
+
             // add new levels above. Don't forget to increase currentFixVersion() for all
             // the storage backends this fix applies to
           default:
@@ -985,7 +1058,30 @@ bool KMyMoneyView::initializeStorage()
   m_fileOpen = true;
   emit kmmFilePlugin(postOpen);
 
-  connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), Models::instance(), SLOT(dataChanged()));
+  Models::instance()->fileOpened();
+
+  // connect the needed signals
+  connect(MyMoneyFile::instance(), SIGNAL(objectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+          Models::instance()->accountsModel(), SLOT(slotObjectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  connect(MyMoneyFile::instance(), SIGNAL(objectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+          Models::instance()->accountsModel(), SLOT(slotObjectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  connect(MyMoneyFile::instance(), SIGNAL(objectRemoved(MyMoneyFile::notificationObjectT,QString)),
+          Models::instance()->accountsModel(), SLOT(slotObjectRemoved(MyMoneyFile::notificationObjectT,QString)));
+  connect(MyMoneyFile::instance(), SIGNAL(balanceChanged(MyMoneyAccount)),
+          Models::instance()->accountsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
+  connect(MyMoneyFile::instance(), SIGNAL(valueChanged(MyMoneyAccount)),
+          Models::instance()->accountsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
+
+  connect(MyMoneyFile::instance(), SIGNAL(objectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+          Models::instance()->institutionsModel(), SLOT(slotObjectAdded(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  connect(MyMoneyFile::instance(), SIGNAL(objectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)),
+          Models::instance()->institutionsModel(), SLOT(slotObjectModified(MyMoneyFile::notificationObjectT,MyMoneyObject*const)));
+  connect(MyMoneyFile::instance(), SIGNAL(objectRemoved(MyMoneyFile::notificationObjectT,QString)),
+          Models::instance()->institutionsModel(), SLOT(slotObjectRemoved(MyMoneyFile::notificationObjectT,QString)));
+  connect(MyMoneyFile::instance(), SIGNAL(balanceChanged(MyMoneyAccount)),
+          Models::instance()->institutionsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
+  connect(MyMoneyFile::instance(), SIGNAL(valueChanged(MyMoneyAccount)),
+          Models::instance()->institutionsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
 
   // inform everyone about new data
   MyMoneyFile::instance()->preloadCache();
@@ -1091,17 +1187,17 @@ void KMyMoneyView::saveToLocalFile(const QString& localFile, IMyMoneyStorageForm
   ft.commit();
 
   pWriter->setProgressCallback(&KMyMoneyView::progressCallback);
-  dev->resetStatus();
   pWriter->writeFile(dev, dynamic_cast<IMyMoneySerialize*>(MyMoneyFile::instance()->storage()));
   MyMoneyFile::instance()->blockSignals(blocked);
-  if (statusDevice->status() != IO_Ok) {
+  QFile *fileStatusDevice = qobject_cast<QFile*>(statusDevice);
+  if (fileStatusDevice->error() != QFile::NoError) {
     throw new MYMONEYEXCEPTION(i18n("Failure while writing to '%1'", localFile));
   }
   pWriter->setProgressCallback(0);
 
   if (base != 0) {
     dev->close();
-    if (statusDevice->status() != IO_Ok) {
+    if (fileStatusDevice->error() != QFile::NoError) {
       delete dev;
       dev = 0;
       throw new MYMONEYEXCEPTION(i18n("Failure while writing to '%1'", localFile));
@@ -1162,6 +1258,10 @@ bool KMyMoneyView::saveFile(const KUrl& url, const QString& keyList)
         int mask = umask((~fmode) & 0777);
         umask(mask);
         try {
+          unsigned int nbak = KMyMoneyGlobalSettings::autoBackupCopies();
+          if (nbak) {
+            KSaveFile::numberedBackupFile(filename, QString(), QString::fromLatin1("~"), nbak);
+          }
           saveToLocalFile(filename, pWriter, plaintext, keyList);
         } catch (MyMoneyException* e) {
           delete e;
@@ -1281,7 +1381,15 @@ void KMyMoneyView::newFile(void)
 void KMyMoneyView::slotSetBaseCurrency(const MyMoneySecurity& baseCurrency)
 {
   if (!baseCurrency.id().isEmpty()) {
-    if (baseCurrency.id() != MyMoneyFile::instance()->baseCurrency().id()) {
+    QString baseId;
+    try {
+      baseId = MyMoneyFile::instance()->baseCurrency().id();
+    } catch (MyMoneyException *e) {
+      qDebug("%s", qPrintable(e->what()));
+      delete e;
+    }
+
+    if (baseCurrency.id() != baseId) {
       MyMoneyFileTransaction ft;
       try {
         MyMoneyFile::instance()->setBaseCurrency(baseCurrency);
@@ -1299,14 +1407,29 @@ void KMyMoneyView::selectBaseCurrency(void)
   MyMoneyFile* file = MyMoneyFile::instance();
 
   // check if we have a base currency. If not, we need to select one
-  if (file->baseCurrency().id().isEmpty()) {
+  QString baseId;
+  try {
+    baseId = MyMoneyFile::instance()->baseCurrency().id();
+  } catch (MyMoneyException *e) {
+    qDebug("%s", qPrintable(e->what()));
+    delete e;
+  }
+
+  if (baseId.isEmpty()) {
     QPointer<KCurrencyEditDlg> dlg = new KCurrencyEditDlg(this);
-    connect(dlg, SIGNAL(selectBaseCurrency(const MyMoneySecurity&)), this, SLOT(slotSetBaseCurrency(const MyMoneySecurity&)));
+    connect(dlg, SIGNAL(selectBaseCurrency(MyMoneySecurity)), this, SLOT(slotSetBaseCurrency(MyMoneySecurity)));
     dlg->exec();
     delete dlg;
   }
 
-  if (!file->baseCurrency().id().isEmpty()) {
+  try {
+    baseId = MyMoneyFile::instance()->baseCurrency().id();
+  } catch (MyMoneyException *e) {
+    qDebug("%s", qPrintable(e->what()));
+    delete e;
+  }
+
+  if (!baseId.isEmpty()) {
     // check that all accounts have a currency
     QList<MyMoneyAccount> list;
     file->accountList(list);
@@ -1321,8 +1444,16 @@ void KMyMoneyView::selectBaseCurrency(void)
 
 
     for (it = list.begin(); it != list.end(); ++it) {
-      if ((*it).currencyId().isEmpty() || (*it).currencyId().length() == 0) {
-        (*it).setCurrencyId(file->baseCurrency().id());
+      QString cid;
+      try {
+        if (!(*it).currencyId().isEmpty() || (*it).currencyId().length() != 0)
+          cid = MyMoneyFile::instance()->currency((*it).currencyId()).id();
+      } catch (MyMoneyException *e) {
+        delete e;
+      }
+
+      if (cid.isEmpty()) {
+        (*it).setCurrencyId(baseId);
         MyMoneyFileTransaction ft;
         try {
           file->modifyAccount(*it);
@@ -1489,6 +1620,7 @@ void KMyMoneyView::loadDefaultCurrencies(void)
   loadDefaultCurrency(MyMoneySecurity("WST", i18n("Samoan Tala")), create);
   loadDefaultCurrency(MyMoneySecurity("STD", i18n("Sao Tome and Principe Dobra")), create);
   loadDefaultCurrency(MyMoneySecurity("SAR", i18n("Saudi Riyal")), create);
+  loadDefaultCurrency(MyMoneySecurity("RSD", i18n("Serbian Dinar")), create);
   loadDefaultCurrency(MyMoneySecurity("SCR", i18n("Seychelles Rupee")), create);
   loadDefaultCurrency(MyMoneySecurity("SLL", i18n("Sierra Leone Leone")), create);
   loadDefaultCurrency(MyMoneySecurity("SGD", i18n("Singapore Dollar"),       "$"), create);
@@ -1613,14 +1745,14 @@ void KMyMoneyView::viewAccountList(const QString& /*selectAccount*/)
 void KMyMoneyView::slotRefreshViews()
 {
   // turn off sync between ledger and investment view
-  disconnect(m_investmentView, SIGNAL(accountSelected(const MyMoneyObject&)), m_ledgerView, SLOT(slotSelectAccount(const MyMoneyObject&)));
-  disconnect(m_ledgerView, SIGNAL(accountSelected(const MyMoneyObject&)), m_investmentView, SLOT(slotSelectAccount(const MyMoneyObject&)));
+  disconnect(m_investmentView, SIGNAL(accountSelected(MyMoneyObject)), m_ledgerView, SLOT(slotSelectAccount(MyMoneyObject)));
+  disconnect(m_ledgerView, SIGNAL(accountSelected(MyMoneyObject)), m_investmentView, SLOT(slotSelectAccount(MyMoneyObject)));
 
 
   // TODO turn sync between ledger and investment view if selected by user
   if (KMyMoneyGlobalSettings::syncLedgerInvestment()) {
-    connect(m_investmentView, SIGNAL(accountSelected(const MyMoneyObject&)), m_ledgerView, SLOT(slotSelectAccount(const MyMoneyObject&)));
-    connect(m_ledgerView, SIGNAL(accountSelected(const MyMoneyObject&)), m_investmentView, SLOT(slotSelectAccount(const MyMoneyObject&)));
+    connect(m_investmentView, SIGNAL(accountSelected(MyMoneyObject)), m_ledgerView, SLOT(slotSelectAccount(MyMoneyObject)));
+    connect(m_ledgerView, SIGNAL(accountSelected(MyMoneyObject)), m_investmentView, SLOT(slotSelectAccount(MyMoneyObject)));
   }
 
   showTitleBar(KMyMoneyGlobalSettings::showTitleBar());
@@ -1663,6 +1795,12 @@ void KMyMoneyView::slotCurrentPageChanged(const QModelIndex current, const QMode
    Instead, create a new function, fixFile_n, and modify the initializeStorage()
    logic above to call it */
 
+void KMyMoneyView::fixFile_3(void)
+{
+  // make sure each storage object contains a (unique) id
+  MyMoneyFile::instance()->storageId();
+}
+
 void KMyMoneyView::fixFile_2(void)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
@@ -2187,18 +2325,14 @@ KMyMoneyViewBase* KMyMoneyView::addBasePage(const QString& title, const QString&
 {
   KMyMoneyViewBase* viewBase = new KMyMoneyViewBase(this, title, title);
 
-  //avoid setting this page as the last selected page since this is called by plugins adding to the view interface
-  disconnect(this, SIGNAL(currentPageChanged(const QModelIndex, const QModelIndex)), this, SLOT(slotRememberPage(const QModelIndex, const QModelIndex)));
+  connect(viewBase, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
   KPageWidgetItem* frm = m_model->addPage(viewBase, title);
   frm->setIcon(KIcon(icon));
 
-  connect(this, SIGNAL(currentPageChanged(const QModelIndex, const QModelIndex)), this, SLOT(slotRememberPage(const QModelIndex, const QModelIndex)));
-
   return viewBase;
 }
 
-
 /* ------------------------------------------------------------------------ */
 /*                 KMyMoneyViewBase                                         */
 /* ------------------------------------------------------------------------ */
