@@ -33,6 +33,7 @@
 #include <QRect>
 #include <QList>
 #include <QVBoxLayout>
+#include <QPixmapCache>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -45,7 +46,6 @@
 
 #include <mymoneyutils.h>
 #include <mymoneyfile.h>
-#include <kmymoneychecklistitem.h>
 #include "kmymoneyutils.h"
 #include "kmymoneyglobalsettings.h"
 
@@ -273,7 +273,14 @@ int AccountSet::load(kMyMoneyAccountSelector* selector)
   // create the favorite section first and sort it to the beginning
   key = QString("A%1").arg(i18n("Favorites"));
   m_favorites = selector->newItem(i18n("Favorites"), key);
-  m_favorites->setIcon(0, QIcon(DesktopIcon("account")));  //krazy:exclude=iconnames
+
+  //get the account icon from cache or insert it if it is not there
+  QPixmap accountPixmap;
+  if (!QPixmapCache::find("account", accountPixmap)) {
+    accountPixmap = DesktopIcon("account"); //krazy:exclude=iconnames
+    QPixmapCache::insert("account", accountPixmap);
+  }
+  m_favorites->setIcon(0, QIcon(accountPixmap));
 
   for (int mask = 0x01; mask != KMyMoneyUtils::last; mask <<= 1) {
     QTreeWidgetItem* item = 0;
@@ -349,9 +356,9 @@ int AccountSet::load(kMyMoneyAccountSelector* selector)
             count += loadSubAccounts(selector, subItem, tmpKey, acc.accountList());
           }
 
-          //disable the item if it has been added only because a subaccount matches the type
+          // the item is not selectable if it has been added only because a subaccount matches the type
           if (!m_typeList.contains(acc.accountType())) {
-            subItem->setDisabled(true);
+            selector->setSelectable(subItem, false);
           }
           subItem->sortChildren(1, Qt::AscendingOrder);
         }
@@ -446,9 +453,9 @@ int AccountSet::loadSubAccounts(kMyMoneyAccountSelector* selector, QTreeWidgetIt
         count += loadSubAccounts(selector, item, tmpKey, acc.accountList());
       }
 
-      //disable the item if it has been added only because a subaccount matches the type
+      // the item is not selectable if it has been added only because a subaccount matches the type
       if (!m_typeList.contains(acc.accountType())) {
-        item->setDisabled(true);
+        selector->setSelectable(item, false);
       }
       item->sortChildren(1, Qt::AscendingOrder);
     }
