@@ -169,6 +169,13 @@ void KMyMoneyCombo::mousePressEvent(QMouseEvent *e)
   if (m_timer.isActive()) {
     m_timer.stop();
     m_completion->slotMakeCompletion("");
+    // the above call clears the selection in the selector but maintains the current index, use that index to restore the selection
+    QTreeWidget* listView = selector()->listView();
+    QModelIndex currentIndex = listView->currentIndex();
+    if (currentIndex.isValid()) {
+      listView->selectionModel()->select(currentIndex, QItemSelectionModel::Select);
+      listView->scrollToItem(listView->currentItem());
+    }
   } else {
     KConfig config("kcminputrc");
     KConfigGroup grp = config.group("KDE");
@@ -210,20 +217,25 @@ void KMyMoneyCombo::keyPressEvent(QKeyEvent* e)
 
 void KMyMoneyCombo::connectNotify(const char* signal)
 {
-  if (signal && QLatin1String(signal) != QLatin1String(QMetaObject::normalizedSignature(SIGNAL(createItem(const QString&, QString&))))) {
+  if (signal && QLatin1String(signal) != QLatin1String(QMetaObject::normalizedSignature(SIGNAL(createItem(QString,QString&))))) {
     m_canCreateObjects = true;
   }
 }
 
 void KMyMoneyCombo::disconnectNotify(const char* signal)
 {
-  if (signal && QLatin1String(signal) != QLatin1String(QMetaObject::normalizedSignature(SIGNAL(createItem(const QString&, QString&))))) {
+  if (signal && QLatin1String(signal) != QLatin1String(QMetaObject::normalizedSignature(SIGNAL(createItem(QString,QString&))))) {
     m_canCreateObjects = false;
   }
 }
 
 void KMyMoneyCombo::focusOutEvent(QFocusEvent* e)
 {
+  // don't do anything if the focus is lost due to window activation, this way switching
+  // windows while typing a category will not popup the category creation dialog
+  if (e->reason() == Qt::ActiveWindowFocusReason)
+    return;
+
   if (m_inFocusOutEvent) {
     KComboBox::focusOutEvent(e);
     return;
