@@ -30,6 +30,9 @@
 #include <QRegExp>
 #include <QHBoxLayout>
 #include <QApplication>
+#ifdef Q_OS_WIN32                 // krazy:exclude=cpp
+#include <QInputContext>
+#endif
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -37,7 +40,6 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "kmymoneychecklistitem.h"
 #include "kmymoneyglobalsettings.h"
 
 KMyMoneySelector::KMyMoneySelector(QWidget *parent, Qt::WFlags flags) :
@@ -68,18 +70,23 @@ KMyMoneySelector::KMyMoneySelector(QWidget *parent, Qt::WFlags flags) :
   m_selMode = QTreeWidget::MultiSelection;
   setSelectionMode(QTreeWidget::SingleSelection);
 
-  connect(m_treeWidget, SIGNAL(itemPressed(QTreeWidgetItem*, int)), this, SLOT(slotItemPressed(QTreeWidgetItem*, int)));
-  connect(m_treeWidget, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SIGNAL(stateChanged(void)));
+  connect(m_treeWidget, SIGNAL(itemPressed(QTreeWidgetItem*,int)), this, SLOT(slotItemPressed(QTreeWidgetItem*,int)));
+  connect(m_treeWidget, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SIGNAL(stateChanged()));
 }
 
 KMyMoneySelector::~KMyMoneySelector()
 {
+#ifdef Q_OS_WIN32                   //krazy:exclude=cpp
+  // reset the focused widget or else we'll have a crash later
+  // caused by an already free'd focus widget in the input context
+  if (qApp->inputContext()->focusWidget() == m_treeWidget)
+    qApp->inputContext()->setFocusWidget(0);
+#endif
 }
 
 void KMyMoneySelector::clear(void)
 {
   m_treeWidget->clear();
-  m_visibleItem = 0;
 }
 
 void KMyMoneySelector::setSelectable(QTreeWidgetItem *item, bool selectable)
@@ -100,13 +107,13 @@ void KMyMoneySelector::setSelectionMode(const QTreeWidget::SelectionMode mode)
     // make sure, it's either Multi or Single
     if (mode != QTreeWidget::MultiSelection) {
       m_selMode = QTreeWidget::SingleSelection;
-      connect(m_treeWidget, SIGNAL(itemSelectionChanged(void)), this, SIGNAL(stateChanged(void)));
-      connect(m_treeWidget, SIGNAL(itemActivated(QTreeWidgetItem*, int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
-      connect(m_treeWidget, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
+      connect(m_treeWidget, SIGNAL(itemSelectionChanged()), this, SIGNAL(stateChanged()));
+      connect(m_treeWidget, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
+      connect(m_treeWidget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
     } else {
-      disconnect(m_treeWidget, SIGNAL(itemSelectionChanged(void)), this, SIGNAL(stateChanged(void)));
-      disconnect(m_treeWidget, SIGNAL(itemActivated(QTreeWidgetItem*, int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
-      disconnect(m_treeWidget, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
+      disconnect(m_treeWidget, SIGNAL(itemSelectionChanged()), this, SIGNAL(stateChanged()));
+      disconnect(m_treeWidget, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
+      disconnect(m_treeWidget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(slotItemSelected(QTreeWidgetItem*)));
     }
   }
   QWidget::update();
@@ -365,27 +372,7 @@ void KMyMoneySelector::setSelected(const QString& id, const bool state)
 
   // make sure the first one found is visible
   if (it_visible)
-    ensureItemVisible(it_visible);
-}
-
-void KMyMoneySelector::ensureItemVisible(const QTreeWidgetItem *it_v)
-{
-  // for some reason, I could only use the ensureItemVisible() method
-  // of QListView successfully, after the widget was drawn on the screen.
-  // If called before it had no effect (if the item was not visible).
-  //
-  // The solution was to store the item we wanted to see in a local var
-  // and call QListView::ensureItemVisible() about 10ms later in
-  // the slot slotShowSelected.  (ipwizard, 12/29/2003)
-  m_visibleItem = it_v;
-
-  QTimer::singleShot(100, this, SLOT(slotShowSelected()));
-}
-
-void KMyMoneySelector::slotShowSelected(void)
-{
-  if (m_treeWidget && m_visibleItem)
-    m_treeWidget->scrollToItem(m_visibleItem);
+    m_treeWidget->scrollToItem(it_visible);
 }
 
 int KMyMoneySelector::slotMakeCompletion(const QString& _txt)
@@ -488,7 +475,7 @@ int KMyMoneySelector::slotMakeCompletion(const QRegExp& exp)
   if (m_selMode == QTreeWidget::SingleSelection) {
     if (firstMatch) {
       m_treeWidget->setCurrentItem(firstMatch);
-      ensureItemVisible(firstMatch);
+      m_treeWidget->scrollToItem(firstMatch);
     } else
       m_treeWidget->clearSelection();
   }
