@@ -316,6 +316,13 @@ void GroupMarker::paintRegisterCell(QPainter *painter, QStyleOptionViewItemV4 &o
   painter->restore();
 }
 
+void GroupMarker::paintFormCell(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index)
+{
+  Q_UNUSED(painter);
+  Q_UNUSED(option);
+  Q_UNUSED(index);
+}
+
 int GroupMarker::rowHeightHint(void) const
 {
   if (!m_visible)
@@ -468,6 +475,8 @@ Register::Register(QWidget *parent) :
     m_modifiers(Qt::KeyboardModifiers(Qt::NoModifier)),
     m_detailsColumnType(PayeeFirst)
 {
+  // used for custom coloring with the help of the application's stylesheet
+  setObjectName(QLatin1String("register"));
   m_itemDelegate = new RegisterItemDelegate(this);
 
   setEditTriggers(QAbstractItemView::NoEditTriggers);
@@ -512,8 +521,8 @@ Register::Register(QWidget *parent) :
   horizontalHeader()->setClickable(false);
   horizontalHeader()->setContextMenuPolicy(Qt::CustomContextMenu);
 
-  connect(this, SIGNAL(cellClicked(int, int)), this, SLOT(selectItem(int, int)));
-  connect(this, SIGNAL(cellDoubleClicked(int, int)), this, SLOT(slotDoubleClicked(int, int)));
+  connect(this, SIGNAL(cellClicked(int,int)), this, SLOT(selectItem(int,int)));
+  connect(this, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(slotDoubleClicked(int,int)));
 }
 
 Register::~Register()
@@ -1009,7 +1018,6 @@ void Register::focusInEvent(QFocusEvent* ev)
   QTableWidget::focusInEvent(ev);
   if (m_focusItem) {
     m_focusItem->setFocus(true, false);
-    repaintItems(m_focusItem);
   }
 }
 
@@ -1052,7 +1060,6 @@ void Register::focusOutEvent(QFocusEvent* ev)
 {
   if (m_focusItem) {
     m_focusItem->setFocus(false, false);
-    repaintItems(m_focusItem);
   }
   QTableWidget::focusOutEvent(ev);
 }
@@ -1258,25 +1265,10 @@ void Register::adjustColumn(int col)
 #endif
 }
 
-void Register::repaintItems(RegisterItem* first, RegisterItem* last)
-{
-  if (first == 0 && last == 0) {
-    first = firstItem();
-    last = lastItem();
-  }
-
-  if (first == 0)
-    return;
-
-  if (last == 0)
-    last = first;
-
-  // TODO: port the register - trigger a repaint
-}
-
 void Register::clearSelection(void)
 {
   unselectItems();
+  TransactionEditorContainer::clearSelection();
 }
 
 void Register::doSelectItems(int from, int to, bool selected)
@@ -1310,10 +1302,6 @@ void Register::doSelectItems(int from, int to, bool selected)
       }
     }
   }
-
-  // anything changed?
-  if (firstItem || lastItem)
-    repaintItems(firstItem, lastItem);
 }
 
 RegisterItem* Register::itemAtRow(int row) const
@@ -1407,9 +1395,10 @@ void Register::mouseReleaseEvent(QMouseEvent *e)
 void Register::contextMenuEvent(QContextMenuEvent *e)
 {
   if (e->reason() == QContextMenuEvent::Mouse) {
-    // since mouse release event is not called,
-    // we need to fake the right mouse button release here
-    m_mouseButton = Qt::RightButton;
+    // since mouse release event is not called, we need
+    // to reset the mouse button and the modifiers here
+    m_mouseButton = Qt::NoButton;
+    m_modifiers = Qt::NoModifier;
 
     // if a selected item is clicked don't change the selection
     RegisterItem* item = itemAtRow(rowAt(e->y()));
@@ -1456,9 +1445,6 @@ bool Register::setFocusItem(RegisterItem* focusItem)
   if (focusItem && focusItem->canHaveFocus()) {
     if (m_focusItem) {
       m_focusItem->setFocus(false);
-      // issue a repaint here only if we move the focus
-      if (m_focusItem != focusItem)
-        repaintItems(m_focusItem);
     }
     Transaction* item = dynamic_cast<Transaction*>(focusItem);
     if (m_focusItem != focusItem && item) {
@@ -1470,7 +1456,6 @@ bool Register::setFocusItem(RegisterItem* focusItem)
     if (m_listsDirty)
       updateRegister(KMyMoneyGlobalSettings::ledgerLens() | !KMyMoneyGlobalSettings::transactionForm());
     ensureItemVisible(m_focusItem);
-    repaintItems(m_focusItem);
     return true;
   } else
     return false;
@@ -1559,28 +1544,6 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
             break;
         }
       }
-    } else if (buttonState & Qt::RightButton) {
-      // if the right button is pressed then only change the
-      // selection if none of the Shift/Ctrl button is pressed and
-      // one of the following conditions is true:
-      //
-      // a) single transaction is selected
-      // b) multiple transactions are selected and the one to be selected is not
-      if (!(modifiers & (Qt::ShiftModifier | Qt::ControlModifier))) {
-        if ((cnt > 0) && (!item->isSelected())) {
-          okToSelect = sameEntryType;
-          emit aboutToSelectItem(item, okToSelect);
-          if (okToSelect) {
-            // pointer 'item' might have changed. reconstruct it.
-            item = itemById(id);
-            unselectItems();
-            item->setSelected(true);
-            setFocusItem(item);
-          }
-        }
-        if (okToSelect)
-          m_selectAnchor = item;
-      }
     } else {
       // we get here when called by application logic
       emit aboutToSelectItem(item, okToSelect);
@@ -1596,7 +1559,7 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
     }
     if (okToSelect) {
       SelectedTransactions list(this);
-      emit selectionChanged(list);
+      emit transactionsSelected(list);
     }
   }
 }
@@ -1644,14 +1607,15 @@ void Register::slotEnsureItemVisible(void)
   setUpdatesEnabled(false);
   updateRegister();
   setUpdatesEnabled(true);
-  scrollTo(model()->index(m_ensureVisibleItem->startRow(), DetailColumn));
+  // since the item will be made visible at the top of the viewport make the bottom index visible first to make the whole item visible
   scrollTo(model()->index(m_ensureVisibleItem->startRow() + m_ensureVisibleItem->numRowsRegister() - 1, DetailColumn));
+  scrollTo(model()->index(m_ensureVisibleItem->startRow(), DetailColumn));
 }
 
 TransactionSortField KMyMoneyRegister::textToSortOrder(const QString& text)
 {
   for (int idx = 1; idx < static_cast<int>(MaxSortFields); ++idx) {
-    if (text == /*i18n*/(sortOrderText[idx])) {
+    if (text == i18n(qPrintable(sortOrderText[idx]))) {
       return static_cast<TransactionSortField>(idx);
     }
   }
@@ -1662,7 +1626,7 @@ const QString KMyMoneyRegister::sortOrderToText(TransactionSortField idx)
 {
   if (idx < PostDateSort || idx >= MaxSortFields)
     idx = UnknownSort;
-  return /*i18n*/(sortOrderText[idx]);
+  return i18n(qPrintable(sortOrderText[idx]));
 }
 
 QString Register::text(int /*row*/, int /*col*/) const
@@ -1833,6 +1797,8 @@ void Register::scrollPage(int key, Qt::KeyboardModifiers modifiers)
           if (item->isVisible())
             height += item->rowHeightHint();
         } while ((!item->isSelectable() || !item->isVisible()) && item->prevItem());
+        while ((!item->isSelectable() || !item->isVisible()) && item->nextItem())
+          item = item->nextItem();
       }
       break;
     case Qt::Key_PageDown:
@@ -1842,6 +1808,8 @@ void Register::scrollPage(int key, Qt::KeyboardModifiers modifiers)
             height += item->rowHeightHint();
           item = item->nextItem();
         } while ((!item->isSelectable() || !item->isVisible()) && item->nextItem());
+        while ((!item->isSelectable() || !item->isVisible()) && item->prevItem())
+          item = item->prevItem();
       }
       break;
 
@@ -1891,7 +1859,7 @@ void Register::scrollPage(int key, Qt::KeyboardModifiers modifiers)
     handleItemChange(oldFocusItem, modifiers & Qt::ShiftModifier, modifiers & Qt::ControlModifier);
     // tell the world about the changes in selection
     SelectedTransactions list(this);
-    emit selectionChanged(list);
+    emit transactionsSelected(list);
   }
 
   if (m_focusItem && !m_focusItem->isSelected() && m_selectionMode == SingleSelection)
@@ -1920,6 +1888,12 @@ void Register::keyPressEvent(QKeyEvent* ev)
     case Qt::Key_Up:
       scrollPage(ev->key(), ev->modifiers());
       break;
+    case Qt::Key_Enter:
+    case Qt::Key_Return:
+      // don't emit the signal right away but wait until
+      // we come back to the Qt main loop
+      QTimer::singleShot(0, this, SIGNAL(editTransaction()));
+      break;
 
     default:
       QTableWidget::keyPressEvent(ev);
