@@ -145,7 +145,7 @@ public:
   }
 
   void paintRegisterCell(QPainter *painter, QStyleOptionViewItemV4 &option, const QModelIndex &index);
-  void paintFormCell(QPainter */*painter*/, const QStyleOptionViewItem &/*option*/, const QModelIndex &/*index*/) {}
+  void paintFormCell(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index);
 
   int rowHeightHint(void) const;
 
@@ -472,8 +472,6 @@ public:
     return m_account;
   }
 
-  void repaintItems(RegisterItem* first = 0, RegisterItem* last = 0);
-
   /**
     * This method creates group marker items and adds them to the register
     */
@@ -564,8 +562,7 @@ protected slots:
   void slotDoubleClicked(int row, int);
 
 signals:
-  void selectionChanged(void);
-  void selectionChanged(const KMyMoneyRegister::SelectedTransactions& list);
+  void transactionsSelected(const KMyMoneyRegister::SelectedTransactions& list);
   /**
     * This signal is emitted when the focus and selection changes to @p item.
     *
