@@ -113,6 +113,10 @@ void Wizard::setAccount(const MyMoneyAccount& acc)
 {
   m_account = acc;
   m_accountTypePage->setAccount(m_account);
+
+  if (!acc.institutionId().isEmpty()) {
+    m_institutionPage->selectExistingInstitution(acc.institutionId());
+  }
 }
 
 const MyMoneySecurity& Wizard::currency(void) const
@@ -287,13 +291,16 @@ const MyMoneySchedule& Wizard::schedule(void)
       t.addSplit(s);
 
       // interest split
-      s.clearId();
-      s.setAccountId(m_loanSchedulePage->m_interestCategory->selectedItem());
-      s.setShares(MyMoneyMoney::autoCalc);
-      s.setValue(MyMoneyMoney::autoCalc);
-      s.setMemo(i18n("Interest"));
-      s.setAction(MyMoneySplit::ActionInterest);
-      t.addSplit(s);
+      //only add if interest is above zero
+      if (!m_loanDetailsPage->m_interestRate->value().isZero()) {
+        s.clearId();
+        s.setAccountId(m_loanSchedulePage->m_interestCategory->selectedItem());
+        s.setShares(MyMoneyMoney::autoCalc);
+        s.setValue(MyMoneyMoney::autoCalc);
+        s.setMemo(i18n("Interest"));
+        s.setAction(MyMoneySplit::ActionInterest);
+        t.addSplit(s);
+      }
 
       // additional fee splits
       QList<MyMoneySplit> additionalSplits;
@@ -415,10 +422,23 @@ void InstitutionPage::slotNewInstitution(void)
   }
 }
 
-void InstitutionPage::slotSelectInstitution(int id)
+void InstitutionPage::slotSelectInstitution(const int index)
 {
-  m_accountNumber->setEnabled(id != 0);
-  m_iban->setEnabled(id != 0);
+  m_accountNumber->setEnabled(index != 0);
+  m_iban->setEnabled(index != 0);
+}
+
+void InstitutionPage::selectExistingInstitution(const QString& id)
+{
+  QList<MyMoneyInstitution>::const_iterator it = d->m_list.constBegin();
+
+  for (int i = 0; i < d->m_list.length(); ++i) {
+    if (d->m_list[i].id() == id) {
+      m_institutionComboBox->setCurrentIndex(i + 1);
+      slotSelectInstitution(i + 1);
+      break;
+    }
+  }
 }
 
 const MyMoneyInstitution& InstitutionPage::institution(void) const
@@ -466,8 +486,8 @@ AccountTypePage::AccountTypePage(Wizard* wizard) :
   connect(m_typeSelection, SIGNAL(itemSelected(int)), this, SLOT(slotUpdateType(int)));
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadWidgets()));
   connect(m_currencyComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateCurrency()));
-  connect(m_conversionRate, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateConversionRate(const QString&)));
-  connect(m_conversionRate, SIGNAL(valueChanged(const QString&)), this, SLOT(slotPriceWarning()));
+  connect(m_conversionRate, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateConversionRate(QString)));
+  connect(m_conversionRate, SIGNAL(valueChanged(QString)), this, SLOT(slotPriceWarning()));
   connect(m_onlineQuote, SIGNAL(clicked()), this, SLOT(slotGetOnlineQuote()));
 }
 
@@ -663,11 +683,11 @@ CreditCardSchedulePage::CreditCardSchedulePage(Wizard* wizard) :
   m_mandatoryGroup->add(m_payee);
   m_mandatoryGroup->add(m_amount->lineedit());
   m_mandatoryGroup->add(m_paymentAccount);
-  connect(m_paymentAccount, SIGNAL(itemSelected(const QString&)), object(), SIGNAL(completeStateChanged()));
-  connect(m_payee, SIGNAL(itemSelected(const QString&)), object(), SIGNAL(completeStateChanged()));
-  connect(m_date, SIGNAL(dateChanged(const QDate&)), object(), SIGNAL(completeStateChanged()));
+  connect(m_paymentAccount, SIGNAL(itemSelected(QString)), object(), SIGNAL(completeStateChanged()));
+  connect(m_payee, SIGNAL(itemSelected(QString)), object(), SIGNAL(completeStateChanged()));
+  connect(m_date, SIGNAL(dateChanged(QDate)), object(), SIGNAL(completeStateChanged()));
 
-  connect(m_payee, SIGNAL(createItem(const QString&, QString&)), wizard, SIGNAL(createPayee(const QString&, QString&)));
+  connect(m_payee, SIGNAL(createItem(QString,QString&)), wizard, SIGNAL(createPayee(QString,QString&)));
 
   m_reminderCheckBox->setChecked(true);
   connect(m_reminderCheckBox, SIGNAL(toggled(bool)), object(), SIGNAL(completeStateChanged()));
@@ -757,13 +777,13 @@ GeneralLoanInfoPage::GeneralLoanInfoPage(Wizard* wizard) :
 
   slotLoadWidgets();
 
-  connect(m_payee, SIGNAL(createItem(const QString&, QString&)), wizard, SIGNAL(createPayee(const QString&, QString&)));
+  connect(m_payee, SIGNAL(createItem(QString,QString&)), wizard, SIGNAL(createPayee(QString,QString&)));
   connect(m_anyPayments, SIGNAL(activated(int)), object(),  SIGNAL(completeStateChanged()));
   connect(m_recordings, SIGNAL(activated(int)), object(), SIGNAL(completeStateChanged()));
 
   connect(m_interestType, SIGNAL(activated(int)), object(),  SIGNAL(completeStateChanged()));
-  connect(m_interestChangeDateEdit, SIGNAL(dateChanged(const QDate&)), object(),  SIGNAL(completeStateChanged()));
-  connect(m_openingBalance, SIGNAL(textChanged(const QString&)), object(),  SIGNAL(completeStateChanged()));
+  connect(m_interestChangeDateEdit, SIGNAL(dateChanged(QDate)), object(),  SIGNAL(completeStateChanged()));
+  connect(m_openingBalance, SIGNAL(textChanged(QString)), object(),  SIGNAL(completeStateChanged()));
 
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadWidgets()));
 }
@@ -851,10 +871,10 @@ LoanDetailsPage::LoanDetailsPage(Wizard* wizard) :
 
   connect(m_termAmount, SIGNAL(valueChanged(int)), this, SLOT(slotValuesChanged()));
   connect(m_termUnit, SIGNAL(highlighted(int)), this, SLOT(slotValuesChanged()));
-  connect(m_loanAmount, SIGNAL(textChanged(const QString&)), this, SLOT(slotValuesChanged()));
-  connect(m_interestRate, SIGNAL(textChanged(const QString&)), this, SLOT(slotValuesChanged()));
-  connect(m_paymentAmount, SIGNAL(textChanged(const QString&)), this, SLOT(slotValuesChanged()));
-  connect(m_balloonAmount, SIGNAL(textChanged(const QString&)), this, SLOT(slotValuesChanged()));
+  connect(m_loanAmount, SIGNAL(textChanged(QString)), this, SLOT(slotValuesChanged()));
+  connect(m_interestRate, SIGNAL(textChanged(QString)), this, SLOT(slotValuesChanged()));
+  connect(m_paymentAmount, SIGNAL(textChanged(QString)), this, SLOT(slotValuesChanged()));
+  connect(m_balloonAmount, SIGNAL(textChanged(QString)), this, SLOT(slotValuesChanged()));
 
   connect(m_calculateButton, SIGNAL(clicked()), this, SLOT(slotCalculate()));
 }
@@ -961,11 +981,6 @@ void LoanDetailsPage::slotCalculate(void)
       // calculate the interest rate out of the other information
       val = calc.interestRate();
 
-      //FIXME: Allow 0% interest rates when the remaining issues are fixed
-      //BUGS 246103 and 246105 on BKO
-      if (val == 0)
-        throw new MYMONEYEXCEPTION("incorrect fincancial calculation");
-
       m_interestRate->loadText(MyMoneyMoney(static_cast<double>(val)).abs().formatMoney("", 3));
       result = i18n("KMyMoney has calculated the interest rate to %1%.", m_interestRate->lineedit()->text());
 
@@ -1307,7 +1322,7 @@ LoanSchedulePage::LoanSchedulePage(Wizard* wizard) :
 {
   m_mandatoryGroup->add(m_interestCategory->lineEdit());
   m_mandatoryGroup->add(m_paymentAccount->lineEdit());
-  connect(m_interestCategory, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateCategory(const QString&, QString&)));
+  connect(m_interestCategory, SIGNAL(createItem(QString,QString&)), this, SLOT(slotCreateCategory(QString,QString&)));
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadWidgets()));
 }
 
@@ -1500,7 +1515,7 @@ HierarchyPage::HierarchyPage(Wizard* wizard) :
   m_parentAccounts->setModel(m_filterProxyModel);
   m_parentAccounts->sortByColumn(0, Qt::AscendingOrder);
 
-  connect(m_parentAccounts->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)), this, SLOT(parentAccountChanged()));
+  connect(m_parentAccounts->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SLOT(parentAccountChanged()));
 }
 
 void HierarchyPage::enterPage(void)
@@ -1579,7 +1594,7 @@ void AccountSummaryPage::enterPage(void)
     m_dataList->append(QString(i18n("Conversion rate") + ": %1").arg(m_wizard->conversionRate().rate(QString()).formatMoney("", KMyMoneyGlobalSettings::pricePrecision())));
   }
   if (!acc.isLoan() || !m_wizard->openingBalance().isZero())
-    m_dataList->append(QString(i18n("Opening balance") + ": %1").arg(m_wizard->openingBalance().formatMoney(acc, sec)));
+    m_dataList->append(QString(i18n("Opening balance") + ": %1").arg(MyMoneyUtils::formatMoney(m_wizard->openingBalance(), acc, sec)));
 
   if (!m_wizard->m_institutionPage->institution().id().isEmpty()) {
     m_dataList->append(QString(i18n("Institution") + ": %1").arg(m_wizard->m_institutionPage->institution().name()));
@@ -1618,8 +1633,8 @@ void AccountSummaryPage::enterPage(void)
     }
     m_dataList->append(QString(i18n("Interest rate") + ": %1 %").arg(m_wizard->m_loanDetailsPage->m_interestRate->value().formatMoney("", -1)));
     m_dataList->append(i18n("Interest rate is %1", m_wizard->m_generalLoanInfoPage->m_interestType->currentText()));
-    m_dataList->append(QString(i18n("Principal and interest") + ": %1").arg(m_wizard->m_loanDetailsPage->m_paymentAmount->value().formatMoney(acc, sec)));
-    m_dataList->append(QString(i18n("Additional fees") + ": %1").arg(m_wizard->m_loanPaymentPage->additionalFees().formatMoney(acc, sec)));
+    m_dataList->append(QString(i18n("Principal and interest") + ": %1").arg(MyMoneyUtils::formatMoney(m_wizard->m_loanDetailsPage->m_paymentAmount->value(), acc, sec)));
+    m_dataList->append(QString(i18n("Additional fees") + ": %1").arg(MyMoneyUtils::formatMoney(m_wizard->m_loanPaymentPage->additionalFees(), acc, sec)));
     m_dataList->append(QString(i18n("Payment frequency") + ": %1").arg(m_wizard->m_generalLoanInfoPage->m_paymentFrequency->currentText()));
     m_dataList->append(QString(i18n("Payment account") + ": %1").arg(m_wizard->m_loanSchedulePage->m_paymentAccount->currentText()));
 
@@ -1650,13 +1665,13 @@ void AccountSummaryPage::enterPage(void)
       m_dataList->append(QString(i18nc("Schedule occurrence", "Occurrence") + ": %1").arg(i18nc("Once per month schedule occurrence", "Monthly")));
       m_dataList->append(i18n("Paid from %1", paymentAccount.name()));
       m_dataList->append(i18n("Pay to %1", m_wizard->m_schedulePage->m_payee->currentText()));
-      m_dataList->append(QString(i18n("Amount") + ": %1").arg(m_wizard->m_schedulePage->m_amount->value().formatMoney(acc, sec)));
+      m_dataList->append(QString(i18n("Amount") + ": %1").arg(MyMoneyUtils::formatMoney(m_wizard->m_schedulePage->m_amount->value(), acc, sec)));
       m_dataList->append(i18n("First payment due on %1", KGlobal::locale()->formatDate(sch.nextDueDate())));
       m_dataList->append(QString(i18n("Payment method") + ": %1").arg(m_wizard->m_schedulePage->m_method->currentText()));
     }
     if (acc.isLoan()) {
       m_dataList->append(QString(i18n("Occurrence") + ": %1").arg(m_wizard->m_generalLoanInfoPage->m_paymentFrequency->currentText()));
-      m_dataList->append(QString(i18n("Amount") + ": %1").arg((m_wizard->m_loanPaymentPage->basePayment() + m_wizard->m_loanPaymentPage->additionalFees()).formatMoney(acc, sec)));
+      m_dataList->append(QString(i18n("Amount") + ": %1").arg(MyMoneyUtils::formatMoney(m_wizard->m_loanPaymentPage->basePayment() + m_wizard->m_loanPaymentPage->additionalFees(), acc, sec)));
       m_dataList->append(i18n("First payment due on %1", KGlobal::locale()->formatDate(m_wizard->m_loanSchedulePage->firstPaymentDueDate())));
     }
   }
